@@ -181,6 +181,14 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
         <source>Show as text</source>
         <translation>Als Text anzeigen</translation>
     </message>
+    <message>
+        <source>Copy JID</source>
+        <translation>JID kopieren</translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation>Passwort kopieren</translation>
+    </message>
 </context>
 <context>
     <name>BackButton</name>
@@ -217,7 +225,7 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Sie müssen verbunden sein, um Ihr Passwort zu ändern.</translation>
+        <translation type="vanished">Sie müssen verbunden sein, um Ihr Passwort zu ändern.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -231,6 +239,14 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
         <source>Change</source>
         <translation>Ändern</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation>Passwort wurde erfolgreich geändert</translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation>Änderung des Passworts ist fehlgeschlagen: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -282,7 +298,7 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Nachricht verfassen</translation>
+        <translation type="vanished">Nachricht verfassen</translation>
     </message>
     <message>
         <source>Send</source>
@@ -322,7 +338,7 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Titel für versteckte Nachricht</translation>
+        <translation type="vanished">Titel für versteckte Nachricht</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -346,7 +362,7 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
     </message>
     <message>
         <source>Close</source>
-        <translation>Schließen</translation>
+        <translation type="vanished">Schließen</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -358,7 +374,7 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
     </message>
     <message>
         <source>All files</source>
-        <translation>Alle Dateien</translation>
+        <translation type="vanished">Alle Dateien</translation>
     </message>
     <message>
         <source>Copy message</source>
@@ -376,6 +392,25 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
         <source>Quote message</source>
         <translation type="vanished">Nachricht zitieren</translation>
     </message>
+    <message>
+        <source>Close message search bar</source>
+        <translation>Suche schließen</translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation>Spoiler Hinweis</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation>Spoiler-Feld ausblenden</translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation>Nachricht verfassen</translation>
+    </message>
 </context>
 <context>
     <name>ClientWorker</name>
@@ -430,6 +465,29 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
         <translation>Abbrechen</translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Verbindungseinstellungen</translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation>Ändern</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation>Verbindungseinstellungen konnten nicht geändert werden</translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation>Verbindungseinstellungen geändert</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -437,6 +495,21 @@ Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugan
         <translation type="vanished">Aktionen</translation>
     </message>
 </context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation>Host-Name:</translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation>Der Host-Name darf keine Leerzeichen enthalten</translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation>Port:</translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
@@ -490,47 +563,47 @@ Stellen Sie sicher, dass Sie es gesichert haben, wenn Sie sich später noch auf
     <name>EmojiPicker</name>
     <message>
         <source>Favorites</source>
-        <translation>Favoriten</translation>
+        <translation type="vanished">Favoriten</translation>
     </message>
     <message>
         <source>People</source>
-        <translation>Menschen</translation>
+        <translation type="vanished">Menschen</translation>
     </message>
     <message>
         <source>Nature</source>
-        <translation>Natur</translation>
+        <translation type="vanished">Natur</translation>
     </message>
     <message>
         <source>Food</source>
-        <translation>Essen</translation>
+        <translation type="vanished">Essen</translation>
     </message>
     <message>
         <source>Activity</source>
-        <translation>Aktivitäten</translation>
+        <translation type="vanished">Aktivitäten</translation>
     </message>
     <message>
         <source>Travel</source>
-        <translation>Reisen</translation>
+        <translation type="vanished">Reisen</translation>
     </message>
     <message>
         <source>Objects</source>
-        <translation>Gegenstände</translation>
+        <translation type="vanished">Gegenstände</translation>
     </message>
     <message>
         <source>Symbols</source>
-        <translation>Zeichen</translation>
+        <translation type="vanished">Zeichen</translation>
     </message>
     <message>
         <source>Flags</source>
-        <translation>Flaggen</translation>
+        <translation type="vanished">Flaggen</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation>Suche</translation>
+        <translation type="vanished">Suche</translation>
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Emoji suchen</translation>
+        <translation type="vanished">Emoji suchen</translation>
     </message>
 </context>
 <context>
@@ -709,7 +782,7 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
     </message>
     <message>
         <source>Connect</source>
-        <translation>Verbinden</translation>
+        <translation type="vanished">Verbinden</translation>
     </message>
     <message>
         <source>Retry</source>
@@ -771,6 +844,41 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
         <source>Log in using a QR-Code</source>
         <translation type="vanished">Mit einem QR-Code anmelden</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation>Verbindungseinstellungen</translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Verbindungseinstellungen</translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation>Die Verbindungseinstellungen werden nach dem ersten erfolgreichem Login gespeichert. Wenn sie nicht funktionieren, wird die Anmeldeseite geöffnet.</translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation>Aktivieren der manuellen Verbindungseinstellungen</translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation>Port:</translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation>Host-Name:</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Zurücksetzen</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Anwenden</translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -841,6 +949,37 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
         <source>%1 (%2)</source>
         <translation>%1 (%2)</translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation>Ton</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation>Dokument</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Standort</translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation>Bild</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation>Video</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation>Datei</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation>Spoiler</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -1062,7 +1201,7 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
     <name>NewMedia</name>
     <message>
         <source>Ready</source>
-        <translation>Bereit</translation>
+        <translation type="vanished">Bereit</translation>
     </message>
     <message>
         <source>Initializing…</source>
@@ -1104,11 +1243,8 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
     <name>QObject</name>
     <message>
         <source>Mark as read</source>
-        <translation type="unfinished">Als gelesen markieren</translation>
+        <translation>Als gelesen markieren</translation>
     </message>
-</context>
-<context>
-    <name>QmlUtils</name>
     <message>
         <source>Available</source>
         <translation>Verfügbar</translation>
@@ -1133,9 +1269,36 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
         <source>Offline</source>
         <translation>Offline</translation>
     </message>
+</context>
+<context>
+    <name>QmlUtils</name>
+    <message>
+        <source>Available</source>
+        <translation type="vanished">Verfügbar</translation>
+    </message>
+    <message>
+        <source>Free for chat</source>
+        <translation type="vanished">Frei zum Chatten</translation>
+    </message>
+    <message>
+        <source>Away</source>
+        <translation type="vanished">Abwesend</translation>
+    </message>
+    <message>
+        <source>Do not disturb</source>
+        <translation type="vanished">Nicht stören</translation>
+    </message>
+    <message>
+        <source>Away for longer</source>
+        <translation type="vanished">Für längere Zeit abwesend</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="vanished">Offline</translation>
+    </message>
     <message>
         <source>Error</source>
-        <translation>Fehler</translation>
+        <translation type="vanished">Fehler</translation>
     </message>
     <message>
         <source>Invisible</source>
@@ -1159,7 +1322,7 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation>Konnte die Adresse des Servers nicht finden. Bitte überprüfen Sie Ihren Servernamen.</translation>
+        <translation type="vanished">Konnte die Adresse des Servers nicht finden. Bitte überprüfen Sie Ihren Servernamen.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
@@ -1185,6 +1348,10 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation>Der Internetzugang ist nicht gestattet. Bitte überprüfen Sie die Internetzugangskonfiguration Ihres Systems.</translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation>Konnte nicht zum Server verbinden. Bitte überprüfe deine Internetverbindung oder den Server-Namen.</translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -1194,11 +1361,34 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
         <translation>QR-Code scannen</translation>
     </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Erklärung anzeigen</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Ohne QR-Code fortfahren</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Scannen den QR-Code von deinem bestehendem Gerät, um dein Konto zu übertragen.</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Verbinde…</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation>Das Kamera-Format „%1“ wird nicht unterstüzt.</translation>
+    </message>
     <message>
         <source>There is no camera available.</source>
         <translation>Keine Kamera verfügbar.</translation>
@@ -1207,11 +1397,28 @@ Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manag
         <source>Your camera is busy.
 Try to close other applications using the camera.</source>
         <translation>Deine Kamera ist beschäftigt.
+Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
+    <message>
+        <source>Scan QR code</source>
+        <translation type="vanished">QR-Code scannen</translation>
+    </message>
+    <message>
+        <source>There is no camera available.</source>
+        <translation type="vanished">Keine Kamera verfügbar.</translation>
+    </message>
+    <message>
+        <source>Your camera is busy.
+Try to close other applications using the camera.</source>
+        <translation type="vanished">Deine Kamera ist beschäftigt.
 Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translation>
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>Das Kamera-Format „%1“ wird nicht unterstüzt.</translation>
+        <translation type="vanished">Das Kamera-Format „%1“ wird nicht unterstüzt.</translation>
     </message>
     <message>
         <source>Logging in…</source>
@@ -1219,23 +1426,23 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     </message>
     <message>
         <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation>Scannen Sie den QR-Code von Ihrem vorhandenen Gerät, um Ihr Konto zu übertragen.</translation>
+        <translation type="vanished">Scannen Sie den QR-Code von Ihrem vorhandenen Gerät, um Ihr Konto zu übertragen.</translation>
     </message>
     <message>
         <source>Show explanation</source>
-        <translation>Erklärung anzeigen</translation>
+        <translation type="vanished">Erklärung anzeigen</translation>
     </message>
     <message>
         <source>Scan</source>
-        <translation>Scannen</translation>
+        <translation type="vanished">Scannen</translation>
     </message>
     <message>
         <source>Continue without QR code</source>
-        <translation>Ohne QR-Code fortfahren</translation>
+        <translation type="vanished">Ohne QR-Code fortfahren</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation>Verbinden…</translation>
+        <translation type="vanished">Verbinden…</translation>
     </message>
 </context>
 <context>
@@ -1257,11 +1464,11 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Passwort erfolgreich geändert.</translation>
+        <translation type="vanished">Passwort erfolgreich geändert.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Änderung des Passworts ist fehlgeschlagen: %1</translation>
+        <translation type="vanished">Änderung des Passworts ist fehlgeschlagen: %1</translation>
     </message>
 </context>
 <context>
@@ -1328,7 +1535,7 @@ Sie werden Ihr Konto nicht mehr benutzen können!</translation>
     <name>RosterListItem</name>
     <message>
         <source>Error: Please check the JID.</source>
-        <translation>Fehler: Bitte überprüfen Sie die JID.</translation>
+        <translation type="vanished">Fehler: Bitte überprüfen Sie die JID.</translation>
     </message>
     <message>
         <source>Available</source>
@@ -1375,7 +1582,7 @@ Sie werden Ihr Konto nicht mehr benutzen können!</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Versteckte Nachricht</translation>
+        <translation type="vanished">Versteckte Nachricht</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1425,7 +1632,11 @@ Sie werden Ihr Konto nicht mehr benutzen können!</translation>
     </message>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>Möchten Sie wirklich den Kontakt &lt;b&gt;%1&lt;/b&gt; von Ihrer Kontaktliste entfernen?</translation>
+        <translation type="vanished">Möchten Sie wirklich den Kontakt &lt;b&gt;%1&lt;/b&gt; von Ihrer Kontaktliste entfernen?</translation>
+    </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation>Möchtest du wirklich den Kontakt &lt;b&gt;%1&lt;/b&gt; aus deiner Kontaktliste entfernen?</translation>
     </message>
 </context>
 <context>
@@ -1508,7 +1719,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>configure whether this device can be used to log in on a new device</source>
-        <translation>Einstellen, ob dieses Gerät zum Anmelden an einem neuen Gerät verwendet werden kann</translation>
+        <translation type="vanished">Einstellen, ob dieses Gerät zum Anmelden an einem neuen Gerät verwendet werden kann</translation>
     </message>
     <message>
         <source>Remove account from Kaidan</source>
@@ -1526,6 +1737,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation>Konto auf dem Server löschen</translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation>Verbindungseinstellungen</translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation>Einstellen des Host-Namen und Ports der Verbindung zum Server</translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on a new device</source>
+        <translation>Einstellen, ob das Gerät das Passwort übertragen kann</translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1605,7 +1828,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Datei</translation>
+        <translation type="vanished">Datei</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -1618,6 +1841,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation>Profil</translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation>Kontakt umbenennen</translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation>QR-Code anzeigen</translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation>Kontakt entfernen</translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation>Verbundene Geräte</translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
