@@ -87,6 +87,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Show as text</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy JID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BackButton</name>
@@ -123,7 +131,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Pasahitza aldatzeko konektaturik egon behar duzu.</translation>
+        <translation type="vanished">Pasahitza aldatzeko konektaturik egon behar duzu.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -137,6 +145,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Change</source>
         <translation>Aldatu</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation type="unfinished">Akatsa pasahitza aldatzean: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -184,7 +200,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Mezua sortu</translation>
+        <translation type="vanished">Mezua sortu</translation>
     </message>
     <message>
         <source>Image</source>
@@ -216,7 +232,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>«Spoiler» keinua</translation>
+        <translation type="vanished">«Spoiler» keinua</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -236,7 +252,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished">Itxi</translation>
+        <translation type="obsolete">Itxi</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -247,10 +263,25 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>All files</source>
+        <source>Close message search bar</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation type="unfinished">«Spoiler» keinua</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation type="unfinished">Mezua sortu</translation>
+    </message>
+</context>
 <context>
     <name>ClientWorker</name>
     <message>
@@ -304,6 +335,29 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished">Utzi</translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished">Aldatu</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Utzi</translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -311,6 +365,21 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="vanished">Jarduerak</translation>
     </message>
 </context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
@@ -356,53 +425,6 @@ Make sure that you backed it up if you want to use your account later.</source>
         <translation>Deskarga akatsa: %1</translation>
     </message>
 </context>
-<context>
-    <name>EmojiPicker</name>
-    <message>
-        <source>Favorites</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>People</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Nature</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Food</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Activity</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Travel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Objects</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Symbols</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Flags</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Search</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Search emoji</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>EmptyChatPage</name>
     <message>
@@ -562,7 +584,7 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
     <message>
         <source>Connect</source>
-        <translation>Konektatu</translation>
+        <translation type="vanished">Konektatu</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -596,6 +618,41 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>An unknown error occured; see log for details.</source>
         <translation type="vanished">Akats ezezagun bat gertatu da; ikusi xehetasunak log edo erregistroetan.</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -666,6 +723,37 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>%1 (%2)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished">Audioa</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation type="unfinished">Dokumentua</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation type="unfinished">Irudia</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation type="unfinished">Bideoa</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished">Artxiboa</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation type="unfinished">«Spoiler»</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -813,10 +901,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
 </context>
 <context>
     <name>NewMedia</name>
-    <message>
-        <source>Ready</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Initializing…</source>
         <translation type="unfinished"></translation>
@@ -859,9 +943,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Mark as read</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>QmlUtils</name>
     <message>
         <source>Available</source>
         <translation type="unfinished">Eskuragarri</translation>
@@ -886,9 +967,36 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Offline</source>
         <translation type="unfinished">Lineaz kanpo</translation>
     </message>
+</context>
+<context>
+    <name>QmlUtils</name>
+    <message>
+        <source>Available</source>
+        <translation type="obsolete">Eskuragarri</translation>
+    </message>
+    <message>
+        <source>Free for chat</source>
+        <translation type="obsolete">Libre berriketarako</translation>
+    </message>
+    <message>
+        <source>Away</source>
+        <translation type="obsolete">Kanpoan</translation>
+    </message>
+    <message>
+        <source>Do not disturb</source>
+        <translation type="obsolete">Ez molestatu</translation>
+    </message>
+    <message>
+        <source>Away for longer</source>
+        <translation type="obsolete">Kanpoan denbora luzerako</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="obsolete">Lineaz kanpo</translation>
+    </message>
     <message>
         <source>Error</source>
-        <translation type="unfinished">Errorea</translation>
+        <translation type="obsolete">Errorea</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -906,10 +1014,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Error while trying to connect securely.</source>
         <translation type="unfinished">Akatsa segurtasunez konektatzerakoan.</translation>
     </message>
-    <message>
-        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not connect to the server.</source>
         <translation type="obsolete">Ezin izan da zerbitzarira konektatu.</translation>
@@ -934,6 +1038,10 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -943,11 +1051,34 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Konektatzen…</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>There is no camera available.</source>
         <translation type="unfinished"></translation>
@@ -957,29 +1088,12 @@ Your password will be deleted, make sure it is stored in a password manager or y
 Try to close other applications using the camera.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show explanation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scan</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Continue without QR code</source>
-        <translation type="unfinished"></translation>
-    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Konektatzen…</translation>
+        <translation type="obsolete">Konektatzen…</translation>
     </message>
 </context>
 <context>
@@ -1001,11 +1115,11 @@ Try to close other applications using the camera.</source>
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Pasahitza behar bezala aldatu da.</translation>
+        <translation type="vanished">Pasahitza behar bezala aldatu da.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Akatsa pasahitza aldatzean: %1</translation>
+        <translation type="vanished">Akatsa pasahitza aldatzean: %1</translation>
     </message>
 </context>
 <context>
@@ -1067,7 +1181,7 @@ You will not be able to use your account again!</source>
     <name>RosterListItem</name>
     <message>
         <source>Error: Please check the JID.</source>
-        <translation>Errorea: Mesedez egiaztatu JIDa.</translation>
+        <translation type="vanished">Errorea: Mesedez egiaztatu JIDa.</translation>
     </message>
     <message>
         <source>Available</source>
@@ -1114,7 +1228,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>«Spoiler»</translation>
+        <translation type="vanished">«Spoiler»</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1160,7 +1274,11 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>Ziur al zaude &lt;b&gt;%1&lt;/b&gt; kontaktua zure zerrendatik ezabatu nahi duzula?</translation>
+        <translation type="vanished">Ziur al zaude &lt;b&gt;%1&lt;/b&gt; kontaktua zure zerrendatik ezabatu nahi duzula?</translation>
+    </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1237,10 +1355,6 @@ Deletion of message history saved on server</extracomment>
         <source>Account security</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>configure whether this device can be used to log in on a new device</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove account from Kaidan</source>
         <translation type="unfinished"></translation>
@@ -1257,6 +1371,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1318,7 +1444,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Artxiboa</translation>
+        <translation type="vanished">Artxiboa</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -1331,6 +1457,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
