@@ -99,6 +99,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Show as text</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy JID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BackButton</name>
@@ -135,7 +143,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Uw moet verbonden zijn om uw wachtwoord te kunnen veranderen.</translation>
+        <translation type="vanished">Uw moet verbonden zijn om uw wachtwoord te kunnen veranderen.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -149,6 +157,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Change</source>
         <translation>Veranderen</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation type="unfinished">Fout bij het wijzigen van wachtwoord: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -196,7 +212,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Bericht opstellen</translation>
+        <translation type="vanished">Bericht opstellen</translation>
     </message>
     <message>
         <source>Send</source>
@@ -232,7 +248,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Spoilerhint</translation>
+        <translation type="vanished">Spoilerhint</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -252,7 +268,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished">Sluiten</translation>
+        <translation type="obsolete">Sluiten</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -264,7 +280,26 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>All files</source>
-        <translation>Alle bestanden</translation>
+        <translation type="vanished">Alle bestanden</translation>
+    </message>
+    <message>
+        <source>Close message search bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation type="unfinished">Spoilerhint</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation type="unfinished">Bericht opstellen</translation>
     </message>
 </context>
 <context>
@@ -320,6 +355,29 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished">Veranderen</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -327,6 +385,21 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="vanished">Handelingen</translation>
     </message>
 </context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
@@ -376,47 +449,47 @@ Make sure that you backed it up if you want to use your account later.</source>
     <name>EmojiPicker</name>
     <message>
         <source>Favorites</source>
-        <translation>Favorieten</translation>
+        <translation type="vanished">Favorieten</translation>
     </message>
     <message>
         <source>People</source>
-        <translation>Mensen</translation>
+        <translation type="vanished">Mensen</translation>
     </message>
     <message>
         <source>Nature</source>
-        <translation>Natuur</translation>
+        <translation type="vanished">Natuur</translation>
     </message>
     <message>
         <source>Food</source>
-        <translation>Eten</translation>
+        <translation type="vanished">Eten</translation>
     </message>
     <message>
         <source>Activity</source>
-        <translation>Activiteiten</translation>
+        <translation type="vanished">Activiteiten</translation>
     </message>
     <message>
         <source>Travel</source>
-        <translation>Reizigen</translation>
+        <translation type="vanished">Reizigen</translation>
     </message>
     <message>
         <source>Objects</source>
-        <translation>Voorwerpen</translation>
+        <translation type="vanished">Voorwerpen</translation>
     </message>
     <message>
         <source>Symbols</source>
-        <translation>Symbolen</translation>
+        <translation type="vanished">Symbolen</translation>
     </message>
     <message>
         <source>Flags</source>
-        <translation>Vlaggen</translation>
+        <translation type="vanished">Vlaggen</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation>Zoeken</translation>
+        <translation type="vanished">Zoeken</translation>
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Emoji&apos;s zoeken</translation>
+        <translation type="vanished">Emoji&apos;s zoeken</translation>
     </message>
 </context>
 <context>
@@ -562,7 +635,7 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
     <message>
         <source>Connect</source>
-        <translation>Verbind</translation>
+        <translation type="vanished">Verbind</translation>
     </message>
     <message>
         <source>Connecting…</source>
@@ -608,6 +681,41 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Log in using a QR-Code</source>
         <translation type="vanished">Log in met behulp van een QR-code</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -678,6 +786,37 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>%1 (%2)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished">Geluid</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation type="unfinished">Document</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation type="unfinished">Afbeelding</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation type="unfinished">Video</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished">Bestand</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation type="unfinished">Spoiler</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -825,10 +964,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
 </context>
 <context>
     <name>NewMedia</name>
-    <message>
-        <source>Ready</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Initializing…</source>
         <translation type="unfinished"></translation>
@@ -871,36 +1006,60 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Mark as read</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Available</source>
+        <translation type="unfinished">Beschikbaar</translation>
+    </message>
+    <message>
+        <source>Free for chat</source>
+        <translation type="unfinished">Beschikbaar voor gesprek</translation>
+    </message>
+    <message>
+        <source>Away</source>
+        <translation type="unfinished">Afwezig</translation>
+    </message>
+    <message>
+        <source>Do not disturb</source>
+        <translation type="unfinished">Niet storen</translation>
+    </message>
+    <message>
+        <source>Away for longer</source>
+        <translation type="unfinished">Langere tijd afwezig</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="unfinished">Offline</translation>
+    </message>
 </context>
 <context>
     <name>QmlUtils</name>
     <message>
         <source>Available</source>
-        <translation>Beschikbaar</translation>
+        <translation type="vanished">Beschikbaar</translation>
     </message>
     <message>
         <source>Free for chat</source>
-        <translation>Beschikbaar voor gesprek</translation>
+        <translation type="vanished">Beschikbaar voor gesprek</translation>
     </message>
     <message>
         <source>Away</source>
-        <translation>Afwezig</translation>
+        <translation type="vanished">Afwezig</translation>
     </message>
     <message>
         <source>Do not disturb</source>
-        <translation>Niet storen</translation>
+        <translation type="vanished">Niet storen</translation>
     </message>
     <message>
         <source>Away for longer</source>
-        <translation>Langere tijd afwezig</translation>
+        <translation type="vanished">Langere tijd afwezig</translation>
     </message>
     <message>
         <source>Offline</source>
-        <translation>Offline</translation>
+        <translation type="vanished">Offline</translation>
     </message>
     <message>
         <source>Error</source>
-        <translation>Fout</translation>
+        <translation type="vanished">Fout</translation>
     </message>
     <message>
         <source>Invisible</source>
@@ -922,10 +1081,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Error while trying to connect securely.</source>
         <translation type="unfinished">Fout bij het maken van een beveiligde verbinding.</translation>
     </message>
-    <message>
-        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not connect to the server.</source>
         <translation type="obsolete">Kan geen verbinding maken met de server.</translation>
@@ -950,6 +1105,10 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -959,27 +1118,17 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
-        <translation>Scan een QR-code</translation>
+        <translation type="unfinished">Scan een QR-code</translation>
     </message>
     <message>
-        <source>There is no camera available.</source>
-        <translation>Er is geen camera beschikbaar.</translation>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your camera is busy.
-Try to close other applications using the camera.</source>
-        <translation>Uw camera is bezig.
-Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
-    </message>
-    <message>
-        <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>Het cameraformaat &apos;%1&apos; wordt niet ondersteund.</translation>
-    </message>
-    <message>
-        <source>Connecting…</source>
+        <source>Continue without QR code</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -987,16 +1136,46 @@ Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show explanation</source>
+        <source>Connecting…</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
     <message>
-        <source>Scan</source>
-        <translation type="unfinished"></translation>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation type="unfinished">Het cameraformaat &apos;%1&apos; wordt niet ondersteund.</translation>
     </message>
     <message>
-        <source>Continue without QR code</source>
-        <translation type="unfinished"></translation>
+        <source>There is no camera available.</source>
+        <translation type="unfinished">Er is geen camera beschikbaar.</translation>
+    </message>
+    <message>
+        <source>Your camera is busy.
+Try to close other applications using the camera.</source>
+        <translation type="unfinished">Uw camera is bezig.
+Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
+    <message>
+        <source>Scan QR code</source>
+        <translation type="vanished">Scan een QR-code</translation>
+    </message>
+    <message>
+        <source>There is no camera available.</source>
+        <translation type="vanished">Er is geen camera beschikbaar.</translation>
+    </message>
+    <message>
+        <source>Your camera is busy.
+Try to close other applications using the camera.</source>
+        <translation type="vanished">Uw camera is bezig.
+Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
+    </message>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation type="vanished">Het cameraformaat &apos;%1&apos; wordt niet ondersteund.</translation>
     </message>
 </context>
 <context>
@@ -1018,11 +1197,11 @@ Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Uw wachtwoord is veranderd.</translation>
+        <translation type="vanished">Uw wachtwoord is veranderd.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Fout bij het wijzigen van wachtwoord: %1</translation>
+        <translation type="vanished">Fout bij het wijzigen van wachtwoord: %1</translation>
     </message>
 </context>
 <context>
@@ -1088,7 +1267,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Error: Please check the JID.</source>
-        <translation>Fout: Controleer nogmaals het JID.</translation>
+        <translation type="vanished">Fout: Controleer nogmaals het JID.</translation>
     </message>
     <message>
         <source>Available</source>
@@ -1127,7 +1306,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation type="vanished">Spoiler</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1181,7 +1360,11 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>Wil je echt het contact &lt;b&gt;%1&lt;/b&gt; uit je contactenlijst verwijderen?</translation>
+        <translation type="vanished">Wil je echt het contact &lt;b&gt;%1&lt;/b&gt; uit je contactenlijst verwijderen?</translation>
+    </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1262,10 +1445,6 @@ Deletion of message history saved on server</extracomment>
         <source>Account security</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>configure whether this device can be used to log in on a new device</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove account from Kaidan</source>
         <translation type="unfinished"></translation>
@@ -1282,6 +1461,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1336,7 +1527,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Bestand</translation>
+        <translation type="vanished">Bestand</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -1349,6 +1540,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation>Profiel</translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation type="unfinished">Naam van contact veranderen</translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
