@@ -80,6 +80,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Show as text</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy JID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -109,7 +117,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Musisz się połączyć, aby zmienić hasło.</translation>
+        <translation type="vanished">Musisz się połączyć, aby zmienić hasło.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -123,6 +131,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Change</source>
         <translation>Zmień</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation type="unfinished">Zmiana hasła nie powiodła się: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -174,7 +190,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Utwórz wiadomość</translation>
+        <translation type="vanished">Utwórz wiadomość</translation>
     </message>
     <message>
         <source>Image</source>
@@ -206,7 +222,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Tytuł ukrytej wiadomości</translation>
+        <translation type="vanished">Tytuł ukrytej wiadomości</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -226,7 +242,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished">Zamknij</translation>
+        <translation type="obsolete">Zamknij</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -238,7 +254,26 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>All files</source>
-        <translation>Wszystkie pliki</translation>
+        <translation type="vanished">Wszystkie pliki</translation>
+    </message>
+    <message>
+        <source>Close message search bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation type="unfinished">Tytuł ukrytej wiadomości</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation type="unfinished">Utwórz wiadomość</translation>
     </message>
 </context>
 <context>
@@ -294,6 +329,44 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished">Anuluj</translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished">Zmień</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Anuluj</translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
@@ -343,47 +416,47 @@ Make sure that you backed it up if you want to use your account later.</source>
     <name>EmojiPicker</name>
     <message>
         <source>Favorites</source>
-        <translation>Ulubione</translation>
+        <translation type="vanished">Ulubione</translation>
     </message>
     <message>
         <source>People</source>
-        <translation>Ludzie</translation>
+        <translation type="vanished">Ludzie</translation>
     </message>
     <message>
         <source>Nature</source>
-        <translation>Natura</translation>
+        <translation type="vanished">Natura</translation>
     </message>
     <message>
         <source>Food</source>
-        <translation>Żywność</translation>
+        <translation type="vanished">Żywność</translation>
     </message>
     <message>
         <source>Activity</source>
-        <translation>Aktywności</translation>
+        <translation type="vanished">Aktywności</translation>
     </message>
     <message>
         <source>Travel</source>
-        <translation>Podróż</translation>
+        <translation type="vanished">Podróż</translation>
     </message>
     <message>
         <source>Objects</source>
-        <translation>Obiekty</translation>
+        <translation type="vanished">Obiekty</translation>
     </message>
     <message>
         <source>Symbols</source>
-        <translation>Symbole</translation>
+        <translation type="vanished">Symbole</translation>
     </message>
     <message>
         <source>Flags</source>
-        <translation>Flagi</translation>
+        <translation type="vanished">Flagi</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation>Szukaj</translation>
+        <translation type="vanished">Szukaj</translation>
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Szukaj emotikon</translation>
+        <translation type="vanished">Szukaj emotikon</translation>
     </message>
 </context>
 <context>
@@ -518,7 +591,7 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
     <message>
         <source>Connect</source>
-        <translation>Połącz</translation>
+        <translation type="vanished">Połącz</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -556,6 +629,41 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Log in using a QR-Code</source>
         <translation type="vanished">Zaloguj się przy użyciu kodu QR</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -626,6 +734,37 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>%1 (%2)</source>
         <translation type="unfinished">%1 (%2)</translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished">Dźwięk</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation type="unfinished">Dokument</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation type="unfinished">Obraz</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation type="unfinished">Wideo</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished">Pilnik</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation type="unfinished">Ukryta wiadomość</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -773,10 +912,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
 </context>
 <context>
     <name>NewMedia</name>
-    <message>
-        <source>Ready</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Initializing…</source>
         <translation type="unfinished"></translation>
@@ -819,9 +954,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Mark as read</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>QmlUtils</name>
     <message>
         <source>Available</source>
         <translation type="unfinished"></translation>
@@ -846,9 +978,12 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Offline</source>
         <translation type="unfinished">Offline</translation>
     </message>
+</context>
+<context>
+    <name>QmlUtils</name>
     <message>
-        <source>Error</source>
-        <translation type="unfinished"></translation>
+        <source>Offline</source>
+        <translation type="obsolete">Offline</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -866,10 +1001,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Error while trying to connect securely.</source>
         <translation type="unfinished">Błąd podczas próby bezpiecznego połączenia.</translation>
     </message>
-    <message>
-        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not connect to the server.</source>
         <translation type="obsolete">Nie udało się połączyć z serwerem.</translation>
@@ -894,6 +1025,10 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -903,11 +1038,34 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Łączenie…</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>There is no camera available.</source>
         <translation type="unfinished"></translation>
@@ -917,29 +1075,12 @@ Your password will be deleted, make sure it is stored in a password manager or y
 Try to close other applications using the camera.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation type="unfinished"></translation>
-    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Łączenie…</translation>
-    </message>
-    <message>
-        <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show explanation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scan</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Continue without QR code</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Łączenie…</translation>
     </message>
 </context>
 <context>
@@ -961,11 +1102,11 @@ Try to close other applications using the camera.</source>
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Hasło zostało pomyślnie zmienione.</translation>
+        <translation type="vanished">Hasło zostało pomyślnie zmienione.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Zmiana hasła nie powiodła się: %1</translation>
+        <translation type="vanished">Zmiana hasła nie powiodła się: %1</translation>
     </message>
 </context>
 <context>
@@ -1029,10 +1170,6 @@ You will not be able to use your account again!</source>
         <source>Offline</source>
         <translation type="obsolete">Offline</translation>
     </message>
-    <message>
-        <source>Error: Please check the JID.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>RosterManager</name>
@@ -1046,7 +1183,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation type="unfinished">Ukryta wiadomość</translation>
+        <translation type="obsolete">Ukryta wiadomość</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1078,10 +1215,6 @@ You will not be able to use your account again!</source>
 </context>
 <context>
     <name>RosterRemoveContactSheet</name>
-    <message>
-        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete contact</source>
         <translation type="unfinished"></translation>
@@ -1094,6 +1227,10 @@ You will not be able to use your account again!</source>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RosterRenameContactSheet</name>
@@ -1169,10 +1306,6 @@ Deletion of message history saved on server</extracomment>
         <source>Account security</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>configure whether this device can be used to log in on a new device</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove account from Kaidan</source>
         <translation type="unfinished"></translation>
@@ -1189,6 +1322,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1239,7 +1384,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Pilnik</translation>
+        <translation type="vanished">Pilnik</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -1252,6 +1397,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
