@@ -83,6 +83,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Show as text</source>
         <translation>Показати як текст</translation>
     </message>
+    <message>
+        <source>Copy JID</source>
+        <translation>Копіювати JID</translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation>Копіювати пароль</translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -112,7 +120,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Вам слід встановити з&apos;єднання, щоб змінити ваш пароль.</translation>
+        <translation type="vanished">Вам слід встановити з&apos;єднання, щоб змінити ваш пароль.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -126,6 +134,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Change</source>
         <translation>Змінити</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation>Пароль успішно змінено</translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation>Не вдалося змінити пароль: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -177,7 +193,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Створити повідомлення</translation>
+        <translation type="vanished">Створити повідомлення</translation>
     </message>
     <message>
         <source>Image</source>
@@ -209,7 +225,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Підказка до спойлера</translation>
+        <translation type="vanished">Підказка до спойлера</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -233,7 +249,7 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>Close</source>
-        <translation>Закрити</translation>
+        <translation type="vanished">Закрити</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -245,7 +261,26 @@ Never show this QR code to anyone else. It would allow unlimited access to your
     </message>
     <message>
         <source>All files</source>
-        <translation>усі файли</translation>
+        <translation type="vanished">усі файли</translation>
+    </message>
+    <message>
+        <source>Close message search bar</source>
+        <translation>Закрити панель пошуку повідомлення</translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation>Підказка до спойлера</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation>Закрити поле підказки до спойлера</translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation>Створити повідомлення</translation>
     </message>
 </context>
 <context>
@@ -301,6 +336,44 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation>Скасувати</translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Параметри з&apos;єднання</translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation>Змінити</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Скасувати</translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation>Не вдалося змінити параметри з&apos;єднання</translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation>Змінено параметри з&apos;єднання</translation>
+    </message>
+</context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation>Назва вузла:</translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation>У назві вузла не повинно бути пробілів</translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation>Порт:</translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
@@ -354,47 +427,47 @@ Make sure that you backed it up if you want to use your account later.</source>
     <name>EmojiPicker</name>
     <message>
         <source>Favorites</source>
-        <translation>Улюблене</translation>
+        <translation type="vanished">Улюблене</translation>
     </message>
     <message>
         <source>People</source>
-        <translation>Люди</translation>
+        <translation type="vanished">Люди</translation>
     </message>
     <message>
         <source>Nature</source>
-        <translation>Природа</translation>
+        <translation type="vanished">Природа</translation>
     </message>
     <message>
         <source>Food</source>
-        <translation>Їжа</translation>
+        <translation type="vanished">Їжа</translation>
     </message>
     <message>
         <source>Activity</source>
-        <translation>Діяльність</translation>
+        <translation type="vanished">Діяльність</translation>
     </message>
     <message>
         <source>Travel</source>
-        <translation>Подорожі</translation>
+        <translation type="vanished">Подорожі</translation>
     </message>
     <message>
         <source>Objects</source>
-        <translation>Об&apos;єкти</translation>
+        <translation type="vanished">Об&apos;єкти</translation>
     </message>
     <message>
         <source>Symbols</source>
-        <translation>Символи</translation>
+        <translation type="vanished">Символи</translation>
     </message>
     <message>
         <source>Flags</source>
-        <translation>Прапори</translation>
+        <translation type="vanished">Прапори</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation>Пошук</translation>
+        <translation type="vanished">Пошук</translation>
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Шукати емодзі</translation>
+        <translation type="vanished">Шукати емодзі</translation>
     </message>
 </context>
 <context>
@@ -522,7 +595,7 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
     <message>
         <source>Connect</source>
-        <translation>З&apos;єднатися</translation>
+        <translation type="vanished">З&apos;єднатися</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -560,6 +633,41 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Log in using a QR-Code</source>
         <translation type="vanished">Вхід за допомогою QR-коду</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation>Параметри з&apos;єднання</translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Параметри з&apos;єднання</translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation>Параметри з&apos;єднання буде збережено після першого успішного входу до системи. Якщо вони не спрацюють, програма поверне вас до сторінки входу.</translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation>Увімкнути нетипові параметри з&apos;єднання</translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation>Порт:</translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation>Назва вузла:</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Скинути</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Застосувати</translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -630,6 +738,37 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>%1 (%2)</source>
         <translation>%1 (%2)</translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation>Звук</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation>Документ</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Місце</translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation>Зображення</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation>Відео</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation>Файл</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation>Спойлер</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -851,7 +990,7 @@ Your password will be deleted, make sure it is stored in a password manager or y
     <name>NewMedia</name>
     <message>
         <source>Ready</source>
-        <translation>Готово</translation>
+        <translation type="vanished">Готово</translation>
     </message>
     <message>
         <source>Initializing…</source>
@@ -895,9 +1034,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Mark as read</source>
         <translation>Позначити як прочитане</translation>
     </message>
-</context>
-<context>
-    <name>QmlUtils</name>
     <message>
         <source>Available</source>
         <translation>Доступний</translation>
@@ -922,9 +1058,36 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Offline</source>
         <translation>Поза мережею</translation>
     </message>
+</context>
+<context>
+    <name>QmlUtils</name>
+    <message>
+        <source>Available</source>
+        <translation type="vanished">Доступний</translation>
+    </message>
+    <message>
+        <source>Free for chat</source>
+        <translation type="vanished">Вільний для спілкування</translation>
+    </message>
+    <message>
+        <source>Away</source>
+        <translation type="vanished">Відсутність</translation>
+    </message>
+    <message>
+        <source>Do not disturb</source>
+        <translation type="vanished">Не турбувати</translation>
+    </message>
+    <message>
+        <source>Away for longer</source>
+        <translation type="vanished">Довга відсутність</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="vanished">Поза мережею</translation>
+    </message>
     <message>
         <source>Error</source>
-        <translation>Помилка</translation>
+        <translation type="vanished">Помилка</translation>
     </message>
     <message>
         <source>Invisible</source>
@@ -948,7 +1111,7 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation>Не вдалося визначити адресу сервера. Будь ласка, перевірте, чи правильно вказано назву сервера.</translation>
+        <translation type="vanished">Не вдалося визначити адресу сервера. Будь ласка, перевірте, чи правильно вказано назву сервера.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
@@ -978,6 +1141,10 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation>З&apos;єднання з інтернетом заборонено. Будь ласка, перевірте налаштування доступу до інтернету у вашій системі.</translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation>Не вдалося встановити з&apos;єднання із сервером. Будь ласка, перевірте параметри з&apos;єднання або вказану назву сервера.</translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -987,11 +1154,34 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
         <translation>Сканувати QR-код</translation>
     </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Показати пояснення</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Продовжити без QR-коду</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Заскануйте QR-код з вашого наявного пристрою, щоб перенести ваш обліковий запис.</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Встановлюємо з&apos;єднання…</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation>Підтримки формату відеокамери «%1» не передбачено.</translation>
+    </message>
     <message>
         <source>There is no camera available.</source>
         <translation>Немає доступної відеокамери.</translation>
@@ -1000,31 +1190,48 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Your camera is busy.
 Try to close other applications using the camera.</source>
         <translation>Із відеокамерою працює інша програма.
+Спробуйте завершити роботу інших програм, які користуються відеокамерою.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
+    <message>
+        <source>Scan QR code</source>
+        <translation type="vanished">Сканувати QR-код</translation>
+    </message>
+    <message>
+        <source>There is no camera available.</source>
+        <translation type="vanished">Немає доступної відеокамери.</translation>
+    </message>
+    <message>
+        <source>Your camera is busy.
+Try to close other applications using the camera.</source>
+        <translation type="vanished">Із відеокамерою працює інша програма.
 Спробуйте завершити роботу інших програм, які користуються відеокамерою.</translation>
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>Підримки формату відеокамери «%1» не передбачено.</translation>
+        <translation type="vanished">Підримки формату відеокамери «%1» не передбачено.</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation>Встановлення з’єднання…</translation>
+        <translation type="vanished">Встановлення з’єднання…</translation>
     </message>
     <message>
         <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation>Заскануйте QR-код з вашого наявного пристрою, щоб перенести ваш обліковий запис.</translation>
+        <translation type="vanished">Заскануйте QR-код з вашого наявного пристрою, щоб перенести ваш обліковий запис.</translation>
     </message>
     <message>
         <source>Show explanation</source>
-        <translation>Показати пояснення</translation>
+        <translation type="vanished">Показати пояснення</translation>
     </message>
     <message>
         <source>Scan</source>
-        <translation>Сканувати</translation>
+        <translation type="vanished">Сканувати</translation>
     </message>
     <message>
         <source>Continue without QR code</source>
-        <translation>Продовжити без QR-коду</translation>
+        <translation type="vanished">Продовжити без QR-коду</translation>
     </message>
 </context>
 <context>
@@ -1046,11 +1253,11 @@ Try to close other applications using the camera.</source>
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Пароль успішно змінено.</translation>
+        <translation type="vanished">Пароль успішно змінено.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Не вдалося змінити пароль: %1</translation>
+        <translation type="vanished">Не вдалося змінити пароль: %1</translation>
     </message>
 </context>
 <context>
@@ -1113,7 +1320,7 @@ You will not be able to use your account again!</source>
     <name>RosterListItem</name>
     <message>
         <source>Error: Please check the JID.</source>
-        <translation>Помилка: будь ласка, перевірте, чи правильно вказано ідентифікатор Jabber.</translation>
+        <translation type="vanished">Помилка: будь ласка, перевірте, чи правильно вказано ідентифікатор Jabber.</translation>
     </message>
     <message>
         <source>Available</source>
@@ -1156,7 +1363,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Спойлер</translation>
+        <translation type="vanished">Спойлер</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1190,7 +1397,7 @@ You will not be able to use your account again!</source>
     <name>RosterRemoveContactSheet</name>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>Ви справді хочете вилучити запис контакту &lt;b&gt;%1&lt;/b&gt; із вашої книги записів контактів?</translation>
+        <translation type="vanished">Ви справді хочете вилучити запис контакту &lt;b&gt;%1&lt;/b&gt; із вашої книги записів контактів?</translation>
     </message>
     <message>
         <source>Delete contact</source>
@@ -1204,6 +1411,10 @@ You will not be able to use your account again!</source>
         <source>Delete</source>
         <translation>Вилучити</translation>
     </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation>Ви справді хочете вилучити запис контакту &lt;b&gt;%1&lt;/b&gt; з вашого списку контактів?</translation>
+    </message>
 </context>
 <context>
     <name>RosterRenameContactSheet</name>
@@ -1285,7 +1496,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>configure whether this device can be used to log in on a new device</source>
-        <translation>Налаштуйте, чи можна використовувати цей пристрій для входу з нового пристрою</translation>
+        <translation type="vanished">Налаштуйте, чи можна використовувати цей пристрій для входу з нового пристрою</translation>
     </message>
     <message>
         <source>Remove account from Kaidan</source>
@@ -1303,6 +1514,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation>Вилучити обліковий запис з сервера</translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation>Параметри з&apos;єднання</translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation>Налаштувати назву вузла і порт для з&apos;єднання</translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on a new device</source>
+        <translation>Налаштувати, чи можна використовувати цей пристрій для входу на новому пристрої</translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1365,7 +1588,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Файл</translation>
+        <translation type="vanished">Файл</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -1378,6 +1601,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation>Профіль</translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation>Перейменувати запис контакту</translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation>Показати QR-код</translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation>Вилучити контакт</translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation>Пристрої у мережі</translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
