@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -101,5 +101,5 @@ signals:
 private:
 	void saveAvatarsFile();
 
-	QMap<QString, QString> jidAvatarMap;
+	QMap<QString, QString> m_jidAvatarMap;
 };
