@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,24 +31,22 @@
 #pragma once
 
 // Qt
+#include <QList>
 #include <QObject>
 #include <QSettings>
-#include <QTimer>
 // QXmpp
 #include <QXmppClient.h>
 // Kaidan
+#include "AccountManager.h"
 #include "AvatarFileStorage.h"
-#include "BitsOfBinaryImageProvider.h"
-#include "Database.h"
 #include "Enums.h"
-#include "Globals.h"
 #include "MessageModel.h"
 #include "PresenceCache.h"
 #include "RosterModel.h"
 #include "ServerFeaturesCache.h"
 #include "TransferCache.h"
+class AccountManager;
 class LogHandler;
-class Kaidan;
 class ClientWorker;
 class RegistrationManager;
 class RosterManager;
@@ -57,6 +55,7 @@ class DiscoveryManager;
 class VCardManager;
 class UploadManager;
 class DownloadManager;
+class VersionManager;
 
 /**
  * The ClientWorker is used as a QObject-based worker on the ClientThread.
@@ -85,14 +84,15 @@ public:
 	Q_ENUM(ConnectionError)
 
 	struct Caches {
-		Caches(Kaidan *kaidan, RosterDb *rosterDb, MessageDb *msgDb, QObject *parent = nullptr)
-		        : msgModel(new MessageModel(kaidan, msgDb, parent)),
-		          rosterModel(new RosterModel(rosterDb, parent)),
+		Caches(RosterDb *rosterDb, MessageDb *msgDb, QObject *parent = nullptr)
+			: settings(new QSettings(APPLICATION_NAME, APPLICATION_NAME)),
+			  accountManager(new AccountManager(settings, parent)),
+			  msgModel(new MessageModel(msgDb, parent)),
+			  rosterModel(new RosterModel(rosterDb, parent)),
 		          avatarStorage(new AvatarFileStorage(parent)),
 		          serverFeaturesCache(new ServerFeaturesCache(parent)),
 		          presCache(new PresenceCache(parent)),
-		          transferCache(new TransferCache(parent)),
-		          settings(new QSettings(APPLICATION_NAME, APPLICATION_NAME))
+			  transferCache(new TransferCache(parent))
 		{
 			rosterModel->setMessageModel(msgModel);
 		}
@@ -102,30 +102,27 @@ public:
 			delete settings;
 		}
 
+		QSettings *settings;
+		AccountManager *accountManager;
 		MessageModel *msgModel;
 		RosterModel *rosterModel;
 		AvatarFileStorage *avatarStorage;
 		ServerFeaturesCache *serverFeaturesCache;
 		PresenceCache *presCache;
 		TransferCache* transferCache;
-		QSettings *settings;
-	};
-
-	struct Credentials {
-		QString jid;
-		QString jidResourcePrefix;
-		QString password;
-		// if never connected successfully before with these credentials
-		bool isFirstTry;
 	};
 
 	/**
 	 * @param caches All caches running in the main thread for communication with the UI.
-	 * @param kaidan Main back-end class, running in the main thread.
 	 * @param enableLogging If logging of the XMPP stream should be done.
 	 * @param parent Optional QObject-based parent.
 	 */
-	ClientWorker(Caches *caches, Kaidan *kaidan, bool enableLogging, QObject *parent = nullptr);
+	ClientWorker(Caches *caches, bool enableLogging, QObject *parent = nullptr);
+
+	/**
+	 * Initializes this client worker as soon as it runs in a separate thread.
+	 */
+	void initialize();
 
 	VCardManager *vCardManager() const;
 
@@ -141,39 +138,62 @@ public:
 	 */
 	bool isApplicationWindowActive() const;
 
-public slots:
 	/**
-	 * Main function of the client thread
-	 */
-	void main();
-
-	/**
-	 * Sets the new credentials for next connect.
+	 * Starts or enqueues a task which will be executed after successful login (e.g. a
+	 * nickname change).
 	 *
-	 * @param creds The new credentials for the next connect
+	 * This method is called by managers which must call "finishTask()" as soon as the
+	 * task is completed.
+	 *
+	 * If the user is logged out when this method is called, a login is triggered, the
+	 * task is started and a logout is triggered afterwards. However, if this method is
+	 * called before a login with new credentials (e.g. during account registration), the
+	 * task is started after the subsequent login.
+	 *
+	 * @param task task which is run directly if the user is logged in or enqueued to be
+	 * run after an automatic login
 	 */
-	void setCredentials(ClientWorker::Credentials creds)
-	{
-		m_creds = creds;
-	}
+	void startTask(const std::function<void ()> task);
 
+	/**
+	 * Finishes a task started by "startTask()".
+	 *
+	 * This must be called after a possible completion of a pending task.
+	 *
+	 * A logout is triggered when this method is called after the second login with the
+	 * same credentials or later. That means, a logout is not triggered after a login with
+	 * new credentials (e.g. after a registration).
+	 */
+	void finishTask();
+
+public slots:
 	/**
 	 * Connects to the server and logs in with all needed configuration variables.
 	 */
-	void xmppConnect();
-
-	/**
-	 * Connects to the server with a minimal configuration and adds additional variables to it before connecting if a configuration is passed.
-	 *
-	 * @param config
-	 */
-	void connectToServer(QXmppConfiguration config = QXmppConfiguration());
+	void logIn();
 
 	/**
 	 * Connects to the server and requests a data form for account registration.
 	 */
 	void connectToRegister();
 
+	/**
+	 * Connects to the server with a minimal configuration.
+	 *
+	 * Some additional configuration variables can be set by passing a configuration.
+	 *
+	 * @param config configuration with additional variables for connecting to the server
+	 * or nothing if only the minimal configuration should be used
+	 */
+	void connectToServer(QXmppConfiguration config = QXmppConfiguration());
+
+	/**
+	 * Logs out of the server if the client is not already logged out.
+	 *
+	 * @param isApplicationBeingClosed true if the application will be terminated directly after logging out, false otherwise
+	 */
+	void logOut(bool isApplicationBeingClosed = false);
+
 	/**
 	 * Deletes the account data from the client and server.
 	 */
@@ -196,23 +216,15 @@ public slots:
 	 */
 	void handleAccountDeletionFromServerFailed(const QXmppStanza::Error &error);
 
-	/**
-	 * Changes the user's password.
-	 *
-	 * @param newPassword new password to set
-	 */
-	void changePassword(const QString &newPassword);
-
-	/**
-	 * Changes the user's display name.
-	 *
-	 * If the user is not logged in during account registration, the display name is changed on the next login.
-	 *
-	 * @param displayName new name that is shown to contacts
-	 */
-	void changeDisplayName(const QString &displayName);
-
 signals:
+	/**
+	 * Emitted when an authenticated connection to the server is established with new
+	 * credentials for the first time.
+	 *
+	 * The client will be in connected state when this is emitted.
+	 */
+	void loggedInWithNewCredentials();
+
 	/**
 	 * Requests to show a notification for a chat message via the system's notification channel.
 	 *
@@ -222,11 +234,12 @@ signals:
 	 */
 	void showMessageNotificationRequested(const QString &senderJid, const QString &senderName, const QString &message);
 
-	// Those signals are emitted by Kaidan.cpp and are used by this class.
-	void connectRequested();
-	void disconnectRequested();
-	void credentialsUpdated(ClientWorker::Credentials m_creds);
-	void registrationFormRequested();
+	/**
+	 * Emitted when the client's connection state changed.
+	 *
+	 * @param connectionState new connection state
+	 */
+	void connectionStateChanged(Enums::ConnectionState connectionState);
 
 	/**
 	 * Emitted when the client failed to connect to the server.
@@ -259,36 +272,52 @@ private slots:
 	void onDisconnected();
 
 	/**
-	 * Sets a new connection error.
+	 * Handles the change of the connection state.
+	 *
+	 * @param connectionState new connection state
+	 */
+	void onConnectionStateChanged(QXmppClient::State connectionState);
+
+	/**
+	 * Handles a connection error.
+	 *
+	 * @param error new connection error
 	 */
 	void onConnectionError(QXmppClient::Error error);
 
+
 private:
 	/**
-	 * Generates the resource part of a JID with a suffix consisting of a dot followed by random alphanumeric characters.
+	 * Starts a pending (enqueued) task (e.g. a password change) if the variable (e.g. a
+	 * password) could not be changed on the server before because the client was not
+	 * logged in.
 	 *
-	 * @param length number of random alphanumeric characters the suffix should consist of after the dot
+	 * @return true if at least one pending task is started on the second login with the
+	 * same credentials or later, otherwise false
 	 */
-	QString generateJidResourceWithRandomSuffix(const QString &jidResourcePrefix, unsigned int length = 4) const;
+	bool startPendingTasks();
 
 	Caches *m_caches;
-
-	Kaidan *m_kaidan;
 	QXmppClient *m_client;
 	LogHandler *m_logger;
-	Credentials m_creds;
 	bool m_enableLogging;
 
 	RegistrationManager *m_registrationManager;
 	RosterManager *m_rosterManager;
-	MessageHandler *m_msgHandler;
-	DiscoveryManager *m_discoManager;
+	MessageHandler *m_messageHandler;
+	DiscoveryManager *m_discoveryManager;
 	VCardManager *m_vCardManager;
 	UploadManager *m_uploadManager;
 	DownloadManager *m_downloadManager;
+	VersionManager *m_versionManager;
 
+	QList<std::function<void ()>> m_pendingTasks;
+	uint m_activeTasks = 0;
+
+	bool m_isFirstLoginAfterStart = true;
 	bool m_isApplicationWindowActive;
 	bool m_isReconnecting = false;
+	bool m_isDisconnecting = false;
 	QXmppConfiguration m_configToBeUsedOnNextConnect;
 
 	// These variables are used for checking the state of an ongoing account deletion.
@@ -296,7 +325,4 @@ private:
 	bool m_isAccountToBeDeletedFromClientAndServer = false;
 	bool m_isAccountDeletedFromServer = false;
 	bool m_isClientConnectedBeforeAccountDeletionFromServer = true;
-
-	QString m_passwordToBeSetOnNextConnect;
-	QString m_displayNameToBeSetOnNextConnect;
 };
