@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,91 +31,38 @@
 #include "Kaidan.h"
 
 // Qt
-#include <QDebug>
 #include <QGuiApplication>
-#include <QSettings>
 #include <QThread>
+#include <QTimer>
 // QXmpp
-#include <QXmppStanza.h>
-#include "qxmpp-exts/QXmppColorGenerator.h"
 #include "qxmpp-exts/QXmppUri.h"
 // Kaidan
 #include "AvatarFileStorage.h"
 #include "CredentialsValidator.h"
 #include "Database.h"
+#include "Globals.h"
 #include "MessageDb.h"
-#include "MessageModel.h"
 #include "Notifications.h"
-#include "PresenceCache.h"
-#include "QmlUtils.h"
 #include "RosterDb.h"
-#include "RosterModel.h"
 
 Kaidan *Kaidan::s_instance;
 
 Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
-        : QObject(parent),
-          m_database(new Database()),
-          m_dbThrd(new QThread()),
-          m_msgDb(new MessageDb()),
-          m_rosterDb(new RosterDb(m_database)),
-          m_cltThrd(new QThread())
+	: QObject(parent)
 {
 	Q_ASSERT(!s_instance);
 	s_instance = this;
 
+	initializeDatabase();
+	initializeCaches();
+	initializeClientWorker(enableLogging);
+
 	connect(app, &QGuiApplication::applicationStateChanged, this, &Kaidan::handleApplicationStateChanged);
 
-	// Database setup
-	m_database->moveToThread(m_dbThrd);
-	m_msgDb->moveToThread(m_dbThrd);
-	m_rosterDb->moveToThread(m_dbThrd);
-
-	connect(m_dbThrd, &QThread::started, m_database, &Database::openDatabase);
-
-	m_dbThrd->setObjectName("SqlDatabase");
-	m_dbThrd->start();
-
-	// Caching components
-	m_caches = new ClientWorker::Caches(this, m_rosterDb, m_msgDb, this);
-	// Connect the avatar changed signal of the avatarStorage with the NOTIFY signal
-	// of the Q_PROPERTY for the avatar storage (so all avatars are updated in QML)
-	connect(m_caches->avatarStorage, &AvatarFileStorage::avatarIdsChanged,
-	        this, &Kaidan::avatarStorageChanged);
-
-	//
-	// Load settings
-	//
-
-	setJid(m_caches->settings->value(KAIDAN_SETTINGS_AUTH_JID).toString());
-	setJidResourcePrefix(m_caches->settings->value(KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX).toString());
-	setPassword(QByteArray::fromBase64(
-		m_caches->settings->value(KAIDAN_SETTINGS_AUTH_PASSWD).toString().toUtf8()
-	));
-	// Use a default prefix for the JID's resource part if no prefix is already set.
-	if (m_creds.jidResourcePrefix.isEmpty())
-		setJidResourcePrefix(KAIDAN_JID_RESOURCE_DEFAULT_PREFIX);
-	m_creds.isFirstTry = false;
-
-	setPasswordVisibility(PasswordVisibility(
-		m_caches->settings->value(KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY).toUInt()));
-
-	//
-	// Start ClientWorker on new thread
-	//
-
-	m_client = new ClientWorker(m_caches, this, enableLogging);
-	m_client->setCredentials(m_creds);
-	m_client->moveToThread(m_cltThrd);
-
-	connect(m_client, &ClientWorker::connectionErrorChanged, this, &Kaidan::setConnectionError);
-	connect(m_client, &ClientWorker::showMessageNotificationRequested, this, [](const QString &senderJid, const QString &senderName, const QString &message) {
-		Notifications::sendMessageNotification(senderJid, senderName, message);
+	// Log out of the server when the application window is closed.
+	connect(app, &QGuiApplication::lastWindowClosed, this, [this]() {
+		emit logOutRequested(true);
 	});
-	connect(m_cltThrd, &QThread::started, m_client, &ClientWorker::main);
-
-	m_client->setObjectName("XmppClient");
-	m_cltThrd->start();
 }
 
 Kaidan::~Kaidan()
@@ -125,31 +72,19 @@ Kaidan::~Kaidan()
 	s_instance = nullptr;
 }
 
-void Kaidan::start()
+void Kaidan::logIn()
 {
-	if (m_creds.jid.isEmpty() || m_creds.password.isEmpty())
-		emit newCredentialsNeeded();
-	else
-		mainConnect();
-}
-
-void Kaidan::mainConnect()
-{
-	emit m_client->credentialsUpdated(m_creds);
-	emit m_client->connectRequested();
+	emit logInRequested();
 }
 
 void Kaidan::requestRegistrationForm()
 {
-	emit m_client->credentialsUpdated(m_creds);
-	emit m_client->registrationFormRequested();
+	emit registrationFormRequested();
 }
 
-void Kaidan::mainDisconnect()
+void Kaidan::logOut()
 {
-	// disconnect the client if connected or connecting
-	if (m_connectionState != ConnectionState::StateDisconnected)
-		emit m_client->disconnectRequested();
+	emit logOutRequested();
 }
 
 void Kaidan::handleApplicationStateChanged(Qt::ApplicationState applicationState)
@@ -160,10 +95,10 @@ void Kaidan::handleApplicationStateChanged(Qt::ApplicationState applicationState
 		emit applicationWindowActiveChanged(false);
 }
 
-void Kaidan::setConnectionState(QXmppClient::State state)
+void Kaidan::setConnectionState(Enums::ConnectionState connectionState)
 {
-	if (m_connectionState != static_cast<ConnectionState>(state)) {
-		m_connectionState = static_cast<ConnectionState>(state);
+	if (m_connectionState != connectionState) {
+		m_connectionState = connectionState;
 		emit connectionStateChanged();
 
 		// Open the possibly cached URI when connected.
@@ -180,23 +115,10 @@ void Kaidan::setConnectionState(QXmppClient::State state)
 
 void Kaidan::setConnectionError(ClientWorker::ConnectionError error)
 {
-	m_connectionError = error;
-	emit connectionErrorChanged(error);
-}
-
-void Kaidan::deleteCredentials()
-{
-	// Delete the JID.
-	m_caches->settings->remove(KAIDAN_SETTINGS_AUTH_JID);
-	setJid(QString());
-
-	// Delete the password.
-	m_caches->settings->remove(KAIDAN_SETTINGS_AUTH_PASSWD);
-	setPassword(QString());
-
-	setPasswordVisibility(PasswordVisible);
-
-	emit newCredentialsNeeded();
+	if (error != m_connectionError) {
+		m_connectionError = error;
+		emit connectionErrorChanged();
+	}
 }
 
 bool Kaidan::notificationsMuted(const QString &jid)
@@ -210,32 +132,6 @@ void Kaidan::setNotificationsMuted(const QString &jid, bool muted)
 	emit notificationsMutedChanged(jid);
 }
 
-void Kaidan::setJid(const QString &jid)
-{
-	m_creds.jid = jid;
-	// credentials were modified -> first try
-	m_creds.isFirstTry = true;
-	emit jidChanged();
-}
-
-void Kaidan::setJidResourcePrefix(const QString &jidResourcePrefix)
-{
-	// JID resource won't influence the authentication, so we don't need
-	// to set the first try flag and can save it.
-	m_creds.jidResourcePrefix = jidResourcePrefix;
-
-	m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX, jidResourcePrefix);
-	emit jidResourcePrefixChanged();
-}
-
-void Kaidan::setPassword(const QString &password)
-{
-	m_creds.password = password;
-	// credentials were modified -> first try
-	m_creds.isFirstTry = true;
-	emit passwordChanged();
-}
-
 void Kaidan::setPasswordVisibility(PasswordVisibility passwordVisibility)
 {
 	m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY, quint8(passwordVisibility));
@@ -271,33 +167,73 @@ void Kaidan::addOpenUri(const QString &uri)
 quint8 Kaidan::logInByUri(const QString &uri)
 {
 	if (!QXmppUri::isXmppUri(uri)) {
-		notifyForInvalidLoginUri();
 		return quint8(LoginByUriState::InvalidLoginUri);
 	}
 
 	QXmppUri parsedUri(uri);
 
 	if (!CredentialsValidator::isAccountJidValid(parsedUri.jid())) {
-		notifyForInvalidLoginUri();
 		return quint8(LoginByUriState::InvalidLoginUri);
 	}
 
-	setJid(parsedUri.jid());
+	AccountManager::instance()->setJid(parsedUri.jid());
 
-	if (!parsedUri.hasAction(QXmppUri::Login) || !CredentialsValidator::isPasswordValid(parsedUri.password())) {
+	if (parsedUri.action() != QXmppUri::Login || !CredentialsValidator::isPasswordValid(parsedUri.password())) {
 		return quint8(LoginByUriState::PasswordNeeded);
 	}
 
 	// Connect with the extracted credentials.
-	setPassword(parsedUri.password());
-	mainConnect();
+	AccountManager::instance()->setPassword(parsedUri.password());
+	logIn();
 	return quint8(LoginByUriState::Connecting);
 }
 
-void Kaidan::notifyForInvalidLoginUri()
+void Kaidan::initializeDatabase()
 {
-	qWarning() << "[main]" << "No valid login URI found.";
-	emit passiveNotificationRequested(tr("No valid login QR code found."));
+	m_dbThrd = new QThread();
+	m_dbThrd->setObjectName("SqlDatabase");
+
+	m_database = new Database();
+	m_database->moveToThread(m_dbThrd);
+
+	m_msgDb = new MessageDb();
+	m_msgDb->moveToThread(m_dbThrd);
+
+	m_rosterDb = new RosterDb(m_database);
+	m_rosterDb->moveToThread(m_dbThrd);
+
+	connect(m_dbThrd, &QThread::started, m_database, &Database::openDatabase);
+	m_dbThrd->start();
+}
+
+void Kaidan::initializeCaches()
+{
+	m_caches = new ClientWorker::Caches(m_rosterDb, m_msgDb, this);
+
+	// Connect the avatar changed signal of the avatarStorage with the NOTIFY signal
+	// of the Q_PROPERTY for the avatar storage (so all avatars are updated in QML)
+	connect(m_caches->avatarStorage, &AvatarFileStorage::avatarIdsChanged, this, &Kaidan::avatarStorageChanged);
+}
+
+void Kaidan::initializeClientWorker(bool enableLogging)
+{
+	m_cltThrd = new QThread();
+	m_cltThrd->setObjectName("XmppClient");
+
+	m_client = new ClientWorker(m_caches, enableLogging);
+	m_client->moveToThread(m_cltThrd);
+
+	connect(AccountManager::instance(), &AccountManager::credentialsNeeded, this, &Kaidan::credentialsNeeded);
+
+	connect(m_client, &ClientWorker::loggedInWithNewCredentials, this, &Kaidan::loggedInWithNewCredentials);
+	connect(m_client, &ClientWorker::connectionStateChanged, this, &Kaidan::setConnectionState);
+	connect(m_client, &ClientWorker::connectionErrorChanged, this, &Kaidan::setConnectionError);
+	connect(m_client, &ClientWorker::showMessageNotificationRequested, this, [](const QString &senderJid, const QString &senderName, const QString &message) {
+		Notifications::sendMessageNotification(senderJid, senderName, message);
+	});
+
+	connect(m_cltThrd, &QThread::started, m_client, &ClientWorker::initialize);
+	m_cltThrd->start();
 }
 
 ClientWorker *Kaidan::client() const
