@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,18 +31,16 @@
 #pragma once
 
 // Qt
-#include <QColor>
 #include <QObject>
 #include <QString>
 // Kaidan
 #include "ClientWorker.h"
 #include "RegistrationDataFormModel.h"
-#include "Globals.h"
 
 class QGuiApplication;
 class Database;
 class QXmppClient;
-class QXmppStanza;
+class QXmppVersionIq;
 
 /**
  * @class Kaidan Kaidan's Back-End Class
@@ -66,9 +64,6 @@ class Kaidan : public QObject
 	Q_PROPERTY(QSettings* settings READ settings CONSTANT)
 	Q_PROPERTY(quint8 connectionState READ connectionState NOTIFY connectionStateChanged)
 	Q_PROPERTY(quint8 connectionError READ connectionError NOTIFY connectionErrorChanged)
-	Q_PROPERTY(QString jid READ jid WRITE setJid NOTIFY jidChanged)
-	Q_PROPERTY(QString jidResourcePrefix READ jidResourcePrefix WRITE setJidResourcePrefix NOTIFY jidResourcePrefixChanged)
-	Q_PROPERTY(QString password READ password WRITE setPassword NOTIFY passwordChanged)
 	Q_PROPERTY(PasswordVisibility passwordVisibility READ passwordVisibility WRITE setPasswordVisibility NOTIFY passwordVisibilityChanged)
 
 public:
@@ -84,20 +79,22 @@ public:
 
 	static Kaidan *instance();
 
+	/**
+	 * Constructs Kaidan's main object and initializes all components / threads.
+	 *
+	 * @param app GUI application object for managing Kaidan's GUI
+	 * @param enableLogging true to enable logging, otherwise false
+	 */
 	Kaidan(QGuiApplication *app, bool enableLogging = true, QObject *parent = nullptr);
+
 	~Kaidan();
 
 	/**
-	 * Starts connecting (called from QML when ready).
-	 */
-	Q_INVOKABLE void start();
-
-	/**
-	 * Connects to the XMPP server.
+	 * Connects to the XMPP server and logs in to it.
 	 *
-	 * The username and password are retrieved from the the settings file.
+	 * The username and password are retrieved from the settings file.
 	 */
-	Q_INVOKABLE void mainConnect();
+	Q_INVOKABLE void logIn();
 
 	/**
 	 * Connects to the server and requests a data form for account registration.
@@ -105,12 +102,12 @@ public:
 	Q_INVOKABLE void requestRegistrationForm();
 
 	/**
-	 * Disconnects from the XMPP server.
+	 * Logs out of the XMPP server.
 	 *
 	 * This disconnects the client from the server.
 	 * When disconnected, the connectionStateChanged signal is emitted.
 	 */
-	Q_INVOKABLE void mainDisconnect();
+	Q_INVOKABLE void logOut();
 
 	/**
 	 * Returns the current ConnectionState
@@ -125,50 +122,6 @@ public:
 	 */
 	quint8 connectionError() const;
 
-	/**
-	 * Set own JID used for connection
-	 *
-	 * To really change the JID of the current connection, you'll need to
-	 * reconnect.
-	 */
-	void setJid(const QString &jid);
-
-	/**
-	 * Get the current JID
-	 */
-	QString jid() const
-	{
-		return m_creds.jid;
-	}
-
-	/**
-	 * Sets the prefix of the JID's resource part.
-	 *
-	 * The remaining part of the resource is set randomly.
-	 */
-	void setJidResourcePrefix(const QString &jidResourcePrefix);
-
-	/**
-	 * Provides the prefix of the JID's resource part.
-	 */
-	QString jidResourcePrefix() const
-	{
-		return m_creds.jidResourcePrefix;
-	}
-
-	/**
-	 * Set the password for next connection
-	 */
-	void setPassword(const QString &password);
-
-	/**
-	 * Get the currently used password
-	 */
-	QString password() const
-	{
-		return m_creds.password;
-	}
-
 	/**
 	 * Sets the visibility of the password on the account transfer page.
 	 */
@@ -259,6 +212,44 @@ signals:
 	 */
 	void applicationWindowActiveChanged(bool active);
 
+	/**
+	 * Emitted to request a registration form from the server which is set as the
+	 * currently used JID.
+	 */
+	void registrationFormRequested();
+
+	/**
+	 * Emitted when a data form for registration is received from the server.
+	 *
+	 * @param dataFormModel received model for the registration data form
+	 */
+	void registrationFormReceived(DataFormModel *dataFormModel);
+
+	/**
+	 * Emitted to send a completed data form for registration.
+	 */
+	void sendRegistrationForm();
+
+	/**
+	 * Emitted when the account registration failed.
+	 *
+	 * @param error received error
+	 * @param errorMessage message describing the error
+	 */
+	void registrationFailed(quint8 error, const QString &errorMessage);
+
+	/**
+	 * Emitted to log in to the server with the set credentials.
+	 */
+	void logInRequested();
+
+	/**
+	 * Emitted to log out of the server.
+	 *
+	 * @param isApplicationBeingClosed true if the application will be terminated directly after logging out, false otherwise
+	 */
+	void logOutRequested(bool isApplicationBeingClosed = false);
+
 	void avatarStorageChanged();
 
 	/**
@@ -268,36 +259,23 @@ signals:
 	void connectionStateChanged();
 
 	/**
-	 * Emitted when the client failed to connect.
-	 */
-	void connectionErrorChanged(ClientWorker::ConnectionError error);
-
-	/**
-	 * Emitted when the JID was changed
-	 */
-	void jidChanged();
-
-	/**
-	 * Emitted when the prefix of the JID's resource part changed.
-	 */
-	void jidResourcePrefixChanged();
-
-	/**
-	 * Emitted when the used password for logging in has changed
-	 */
-	void passwordChanged();
-
-	/**
-	 * Emitted when there are no (correct) credentials and new are needed
+	 * Emitted when the connection error changed.
 	 *
-	 * The client will be in disconnected state, when this is emitted.
+	 * That is the case when the client failed to connect or it succeeded to connect after an error.
 	 */
-	void newCredentialsNeeded();
+	void connectionErrorChanged();
+
+	/**
+	 * Emitted when there are no (correct) credentials and new ones are needed.
+	 *
+	 * The client will be in disconnected state when this is emitted.
+	 */
+	void credentialsNeeded();
 
 	/**
 	 * Emitted when an authenticated connection to the server is established with new credentials for the first time.
 	 *
-	 * The client will be in connected state, when this is emitted.
+	 * The client will be in connected state when this is emitted.
 	 */
 	void loggedInWithNewCredentials();
 
@@ -366,7 +344,6 @@ signals:
 	/**
 	 * Correct the last message
 	 *
-	 * To get/check the last message id, use `kaidan.messageModel.lastMessageId(jid)`
 	 */
 	void correctMessage(const QString &msgId, const QString &message);
 
@@ -418,14 +395,11 @@ signals:
 	void changePassword(const QString &newPassword);
 
 	/**
-	 * Emitted, when changing the password has succeeded.
+	 * Emitted when changing the user's password failed.
+	 *
+	 * @param errorMessage message describing the error
 	 */
-	void passwordChangeSucceeded();
-
-	/**
-	 * Emitted, when changing the password has failed.
-	 */
-	void passwordChangeFailed();
+	void passwordChangeFailed(const QString &errorMessage);
 
 	/**
 	 * Emitted, when a contact was muted/unmuted.
@@ -442,12 +416,16 @@ signals:
 	 */
 	void deleteAccountFromClient();
 
-	void registrationFormReceived(DataFormModel *dataFormModel);
+	/**
+	  * Requests fetching the version information of all resources of the given
+	  * bare JID
+	  */
+	void requestClientVersions(const QString &bareJid, const QString &resource = {});
 
-	void sendRegistrationForm();
-
-	void registrationSucceeded();
-	void registrationFailed(quint8 error, const QString &errrorMessage);
+	/**
+	  * Emitted when a client version information was received
+	  */
+	void clientVersionReceived(const QXmppVersionIq &versionIq);
 
 public slots:
 	/**
@@ -460,18 +438,13 @@ public slots:
 	/**
 	 * Set current connection state
 	 */
-	void setConnectionState(QXmppClient::State state);
+	void setConnectionState(Enums::ConnectionState connectionState);
 
 	/**
 	 * Sets a new connection error.
 	 */
 	void setConnectionError(ClientWorker::ConnectionError error);
 
-	/**
-	 * Deletes the username and password from the settings file.
-	 */
-	void deleteCredentials();
-
 	/**
 	 * Receives messages from another instance of the application
 	 */
@@ -496,9 +469,21 @@ public slots:
 
 private:
 	/**
-	 * Notifies if no valid login URI was found.
+	 * Initializes the database and the corresponding thread.
 	 */
-	void notifyForInvalidLoginUri();
+	void initializeDatabase();
+
+	/**
+	 * Initializes the caches.
+	 */
+	void initializeCaches();
+
+	/**
+	 * Initializes the client worker and the corresponding thread.
+	 *
+	 * @param enableLogging true to enable logging, otherwise false
+	 */
+	void initializeClientWorker(bool enableLogging = true);
 
 	Database *m_database;
 	QThread *m_dbThrd;
@@ -508,7 +493,6 @@ private:
 	ClientWorker::Caches *m_caches;
 	ClientWorker *m_client;
 
-	ClientWorker::Credentials m_creds;
 	QString m_openUriCache;
 	ConnectionState m_connectionState = ConnectionState::StateDisconnected;
 	ClientWorker::ConnectionError m_connectionError = ClientWorker::NoError;
