@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -38,7 +38,7 @@
 #include <QXmppClient.h>
 #include <QXmppLogger.h>
 
-LogHandler::LogHandler(QXmppClient *client, QObject *parent) : QObject(parent), client(client)
+LogHandler::LogHandler(QXmppClient *client, QObject *parent) : QObject(parent), m_client(client)
 {
 	client->logger()->setLoggingType(QXmppLogger::SignalLogging);
 }
@@ -53,9 +53,9 @@ void LogHandler::enableLogging(bool enabled)
 
 	// apply change: enable or disable
 	if (enabled)
-		connect(client->logger(), &QXmppLogger::message, this, &LogHandler::handleLog);
+		connect(m_client->logger(), &QXmppLogger::message, this, &LogHandler::handleLog);
 	else
-		disconnect(client->logger(), &QXmppLogger::message, this, &LogHandler::handleLog);
+		disconnect(m_client->logger(), &QXmppLogger::message, this, &LogHandler::handleLog);
 }
 
 void LogHandler::handleLog(QXmppLogger::MessageType type, const QString &text)
