@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -63,6 +63,6 @@ private:
 	 */
 	static QString makeXmlPretty(QString inputXml);
 
-	QXmppClient *client;
+	QXmppClient *m_client;
 	bool enabled = false;
 };
