@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,7 +31,9 @@
 #include "Message.h"
 
 #include <QDomElement>
-#include <QMimeType>
+#include <QStringBuilder>
+
+#include "MediaUtils.h"
 
 static bool operator==(const QXmppStanza::Error &left, const QXmppStanza::Error &right) {
 	return left.code() == right.code()
@@ -191,26 +193,6 @@ void Message::setMediaSize(const qint64 &mediaSize)
 	m_mediaSize = mediaSize;
 }
 
-bool Message::isSpoiler() const
-{
-	return m_isSpoiler;
-}
-
-void Message::setIsSpoiler(bool isSpoiler)
-{
-	m_isSpoiler = isSpoiler;
-}
-
-QString Message::spoilerHint() const
-{
-	return m_spoilerHint;
-}
-
-void Message::setSpoilerHint(const QString &spoilerHint)
-{
-	m_spoilerHint = spoilerHint;
-}
-
 QString Message::errorText() const
 {
 	return m_errorText;
@@ -220,3 +202,24 @@ void Message::setErrorText(const QString &errText)
 {
 	m_errorText = errText;
 }
+
+QString Message::previewText() const
+{
+	if (isSpoiler()) {
+		if (spoilerHint().isEmpty()) {
+			return tr("Spoiler");
+		} else {
+			return spoilerHint();
+		}
+	} else {
+		if (mediaType() == Enums::MessageType::MessageText) {
+			return body();
+		} else {
+			const auto text = MediaUtils::mediaTypeName(mediaType());
+
+			if (!body().isEmpty())
+				return text % QStringLiteral(": ") % body();
+			return text;
+		}
+	}
+}
