@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,8 +30,13 @@
 
 #pragma once
 
+// Qt
+#include <QCoreApplication>
+// QXmpp
 #include <QXmppMessage.h>
+// Kaidan
 #include "Enums.h"
+
 class QMimeType;
 
 using namespace Enums;
@@ -43,6 +48,8 @@ using namespace Enums;
  */
 class Message : public QXmppMessage
 {
+	Q_DECLARE_TR_FUNCTIONS(Message)
+
 public:
 	/**
 	 * Compares another @c Message with this. Only attributes that are saved in the
@@ -75,15 +82,15 @@ public:
 	qint64 mediaSize() const;
 	void setMediaSize(const qint64 &mediaSize);
 
-	bool isSpoiler() const;
-	void setIsSpoiler(bool isSpoiler);
-
-	QString spoilerHint() const;
-	void setSpoilerHint(const QString &spoilerHint);
-
 	QString errorText() const;
 	void setErrorText(const QString &errText);
 
+	/**
+	 * Preview of the message in pure text form (used in the contact list for the
+	 * last message for example)
+	 */
+	QString previewText() const;
+
 private:
 	/**
 	 * Media type of the message, e.g. a text or image.
@@ -125,16 +132,6 @@ private:
 	 */
 	QDateTime m_mediaLastModified;
 
-	/**
-	 * True if the message is a spoiler message.
-	 */
-	bool m_isSpoiler = false;
-
-	/**
-	 * Hint of the spoiler message.
-	 */
-	QString m_spoilerHint;
-
 	/**
 	 * Text description of an error if it ever happened to the message
 	 */
