@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -66,7 +66,7 @@ public:
 	};
 	Q_ENUM(MessageRoles)
 
-	MessageModel(Kaidan *kaidan, MessageDb *msgDb, QObject *parent = nullptr);
+	MessageModel(MessageDb *msgDb, QObject *parent = nullptr);
 	~MessageModel();
 
 	Q_REQUIRED_RESULT bool isEmpty() const;
@@ -143,8 +143,7 @@ private:
 	 */
 	void processMessage(Message &msg);
 
-	Kaidan *kaidan;
-	MessageDb *msgDb;
+	MessageDb *m_msgDb;
 
 	QVector<Message> m_messages;
 	QString m_currentChatJid;
