@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,13 +31,14 @@
 #include "QmlUtils.h"
 // Qt
 #include <QClipboard>
-#include <QDebug>
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
 #include <QGuiApplication>
+#include <QImage>
 #include <QMimeDatabase>
 #include <QStandardPaths>
+#include <QStringBuilder>
 #include <QUrl>
 // QXmpp
 #include "qxmpp-exts/QXmppColorGenerator.h"
@@ -68,7 +69,7 @@ QString QmlUtils::connectionErrorMessage(ClientWorker::ConnectionError error)
 {
 	switch (error) {
 	case ClientWorker::NoError:
-		Q_UNREACHABLE();
+		break;
 	case ClientWorker::AuthenticationFailed:
 		return tr("Invalid username or password.");
 	case ClientWorker::NotConnected:
@@ -78,7 +79,7 @@ QString QmlUtils::connectionErrorMessage(ClientWorker::ConnectionError error)
 	case ClientWorker::TlsNotAvailable:
 		return tr("The server doesn't support secure connections.");
 	case ClientWorker::DnsError:
-		return tr("Could not resolve the server's address. Please check your server name.");
+		return tr("Could not connect to the server. Please check your internet connection or your server name.");
 	case ClientWorker::ConnectionRefused:
 		return tr("The server is offline or blocked by a firewall.");
 	case ClientWorker::NoSupportedAuth:
@@ -171,6 +172,52 @@ QColor QmlUtils::getUserColor(const QString &nickName)
 	return {color.red, color.green, color.blue};
 }
 
+QUrl QmlUtils::pasteImage()
+{
+	const auto image = QGuiApplication::clipboard()->image();
+	if (image.isNull())
+		return {};
+
+	// create absolute file path
+	const auto path = downloadPath(u"image-" % timestampForFileName() % u".jpg");
+
+	// encode JPEG image
+	if (!image.save(path, "JPG", JPEG_EXPORT_QUALITY))
+		return {};
+	return QUrl::fromLocalFile(path);
+}
+
+QString QmlUtils::downloadPath(const QString &filename)
+{
+	// Kaidan download directory
+	const QDir directory(
+			QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) %
+				QDir::separator() %
+				APPLICATION_DISPLAY_NAME);
+	// create directory if it doesn't exist
+	if (!directory.mkpath("."))
+		return {};
+
+	// check whether a file with this name already exists
+	QFileInfo info(directory, filename);
+	if (!info.exists())
+		return info.absoluteFilePath();
+
+	// find a new filename that doesn't exist
+	const auto baseName = info.baseName();
+	const auto nameSuffix = info.suffix();
+	for (uint i = 1; info.exists(); i++) {
+		// try to insert '-<i>' before the file extension
+		info = QFileInfo(directory, baseName % u'-' % QString::number(i) % nameSuffix);
+	}
+	return info.absoluteFilePath();
+}
+
+QString QmlUtils::timestampForFileName(const QDateTime &dateTime)
+{
+	return dateTime.toString(u"yyyyMMdd_hhmmss");
+}
+
 QString QmlUtils::processMsgFormatting(const QStringList &list, bool isFirst)
 {
 	if (list.isEmpty())
