@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,12 +30,13 @@
 
 #include "QrCodeGenerator.h"
 
-#include <QDebug>
 #include <QImage>
 #include <QRgb>
 
-#include <stdexcept>
+#include <ZXing/BarcodeFormat.h>
+#include <ZXing/MultiFormatWriter.h>
 
+#include "AccountManager.h"
 #include "Kaidan.h"
 #include "qxmpp-exts/QXmppUri.h"
 
@@ -51,16 +52,24 @@ QImage QrCodeGenerator::generateLoginUriQrCode(int edgePixelCount)
 {
 	QXmppUri uri;
 
-	uri.setJid(Kaidan::instance()->jid());
+	uri.setJid(AccountManager::instance()->jid());
 	uri.setAction(QXmppUri::Login);
 
 	if (Kaidan::instance()->passwordVisibility() != Kaidan::PasswordInvisible)
-		uri.setPassword(Kaidan::instance()->password());
+		uri.setPassword(AccountManager::instance()->password());
 
-	return generateQrCode(uri.toString(), edgePixelCount);
+	return generateQrCode(edgePixelCount, uri.toString());
 }
 
-QImage QrCodeGenerator::generateQrCode(const QString &text, int edgePixelCount)
+QImage QrCodeGenerator::generateBareJidQrCode(int edgePixelCount, const QString &bareJid)
+{
+	QXmppUri uri;
+	uri.setJid(bareJid);
+
+	return generateQrCode(edgePixelCount, uri.toString());
+}
+
+QImage QrCodeGenerator::generateQrCode(int edgePixelCount, const QString &text)
 {
 	try {
 		ZXing::MultiFormatWriter writer(ZXing::BarcodeFormat::QR_CODE);
