@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -37,7 +37,6 @@
 #include "Message.h"
 #include "MessageDb.h"
 // Qt
-#include <QDateTime>
 #include <QSqlDriver>
 #include <QSqlField>
 #include <QSqlQuery>
@@ -53,6 +52,7 @@ RosterDb::RosterDb(Database *db, QObject *parent)
 	s_instance = this;
 
 	connect(this, &RosterDb::fetchItemsRequested, this, &RosterDb::fetchItems);
+	connect(this, &RosterDb::updateItemRequested, this, &RosterDb::updateItem);
 }
 
 RosterDb::~RosterDb()
@@ -267,7 +267,7 @@ void RosterDb::fetchItems(const QString &accountId)
 	for (auto &item : items) {
 		Message lastMessage = MessageDb::instance()->fetchLastMessage(accountId, item.jid());
 		item.setLastExchanged(lastMessage.stamp());
-		item.setLastMessage(lastMessage.body());
+		item.setLastMessage(lastMessage.previewText());
 	}
 
 	emit itemsFetched(items);
