@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,8 +30,6 @@
 
 #pragma once
 
-// C++
-#include <functional>
 // Qt
 #include <QObject>
 class QSqlQuery;
@@ -64,6 +62,8 @@ public:
 signals:
 	void fetchItemsRequested(const QString &accountId);
 	void itemsFetched(const QVector<RosterItem> &items);
+	void updateItemRequested(const QString &jid,
+	                         const std::function<void (RosterItem &)> &updateItem);
 
 public slots:
 	void addItem(const RosterItem &item);
