@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,23 +30,18 @@
 
 #include "RosterManager.h"
 // Kaidan
-#include "ClientWorker.h"
-#include "Globals.h"
 #include "Kaidan.h"
 #include "VCardManager.h"
 // QXmpp
 #include <QXmppClient.h>
 #include <QXmppRosterManager.h>
-#include <QXmppUtils.h>
 
-RosterManager::RosterManager(Kaidan *kaidan,
-                             QXmppClient *client,
+RosterManager::RosterManager(QXmppClient *client,
                              RosterModel *model,
                              AvatarFileStorage *avatarStorage,
                              VCardManager *vCardManager,
                              QObject *parent)
-    : QObject(parent),
-	  m_kaidan(kaidan),
+	: QObject(parent),
 	  m_client(client),
 	  m_model(model),
 	  m_avatarStorage(avatarStorage),
@@ -60,7 +55,7 @@ RosterManager::RosterManager(Kaidan *kaidan,
 		this, [this, vCardManager, model] (const QString &jid) {
 		emit model->addItemRequested(RosterItem(m_manager->getRosterEntry(jid)));
 
-		vCardManager->fetchVCard(jid);
+		vCardManager->requestVCard(jid);
 	});
 
 	connect(m_manager, &QXmppRosterManager::itemChanged,
@@ -73,11 +68,11 @@ RosterManager::RosterManager(Kaidan *kaidan,
 	connect(m_manager, &QXmppRosterManager::itemRemoved, model, &RosterModel::removeItemRequested);
 
 	connect(m_manager, &QXmppRosterManager::subscriptionReceived,
-	        this, [kaidan] (const QString &jid) {
+			this, [] (const QString &jid) {
 		// emit signal to ask user
-		emit kaidan->subscriptionRequestReceived(jid, QString());
+		emit Kaidan::instance()->subscriptionRequestReceived(jid, QString());
 	});
-	connect(kaidan, &Kaidan::subscriptionRequestAnswered,
+	connect(Kaidan::instance(), &Kaidan::subscriptionRequestAnswered,
 	        this, [=] (QString jid, bool accepted) {
 		if (accepted) {
 			m_manager->acceptSubscription(jid);
@@ -91,15 +86,10 @@ RosterManager::RosterManager(Kaidan *kaidan,
 		}
 	});
 
-	connect(kaidan->messageModel(), &MessageModel::currentChatJidChanged, this, &RosterManager::setCurrentChatJid);
-
 	// user actions
-	connect(kaidan, &Kaidan::addContact, this, &RosterManager::addContact);
-	connect(kaidan, &Kaidan::removeContact, this, &RosterManager::removeContact);
-	connect(kaidan, &Kaidan::renameContact, this, &RosterManager::renameContact);
-	connect(kaidan, &Kaidan::sendMessage, this, &RosterManager::handleSendMessage);
-
-	connect(client, &QXmppClient::messageReceived, this, &RosterManager::handleMessage);
+	connect(Kaidan::instance(), &Kaidan::addContact, this, &RosterManager::addContact);
+	connect(Kaidan::instance(), &Kaidan::removeContact, this, &RosterManager::removeContact);
+	connect(Kaidan::instance(), &Kaidan::renameContact, this, &RosterManager::renameContact);
 }
 
 void RosterManager::populateRoster()
@@ -113,25 +103,20 @@ void RosterManager::populateRoster()
 		items[jid] = RosterItem(m_manager->getRosterEntry(jid), currentTime);
 
 		if (m_avatarStorage->getHashOfJid(jid).isEmpty())
-			m_vCardManager->fetchVCard(jid);
+			m_vCardManager->requestVCard(jid);
 	}
 
 	// replace current contacts with new ones from server
 	emit m_model->replaceItemsRequested(items);
 }
 
-void RosterManager::setCurrentChatJid(const QString &currentChatJid)
-{
-	m_currentChatJid = currentChatJid;
-}
-
 void RosterManager::addContact(const QString &jid, const QString &name, const QString &msg)
 {
 	if (m_client->state() == QXmppClient::ConnectedState) {
 		m_manager->addItem(jid, name);
 		m_manager->subscribe(jid, msg);
 	} else {
-		emit m_kaidan->passiveNotificationRequested(
+		emit Kaidan::instance()->passiveNotificationRequested(
 			tr("Could not add contact, as a result of not being connected.")
 		);
 		qWarning() << "[client] [RosterManager] Could not add contact, as a result of "
@@ -145,7 +130,7 @@ void RosterManager::removeContact(const QString &jid)
 		m_manager->unsubscribe(jid);
 		m_manager->removeItem(jid);
 	} else {
-		emit m_kaidan->passiveNotificationRequested(
+		emit Kaidan::instance()->passiveNotificationRequested(
 			tr("Could not remove contact, as a result of not being connected.")
 		);
 		qWarning() << "[client] [RosterManager] Could not remove contact, as a result of "
@@ -158,66 +143,10 @@ void RosterManager::renameContact(const QString &jid, const QString &newContactN
 	if (m_client->state() == QXmppClient::ConnectedState) {
 		m_manager->renameItem(jid, newContactName);
 	} else {
-		emit m_kaidan->passiveNotificationRequested(
+		emit Kaidan::instance()->passiveNotificationRequested(
 			tr("Could not rename contact, as a result of not being connected.")
 		);
 		qWarning() << "[client] [RosterManager] Could not rename contact, as a result of "
 		              "not being connected.";
 	}
 }
-
-void RosterManager::handleSendMessage(const QString &jid, const QString &message,
-                                      bool isSpoiler, const QString &spoilerHint)
-{
-	if (m_client->state() == QXmppClient::ConnectedState) {
-		// update roster item
-		const QString lastMessage =
-		        isSpoiler ? spoilerHint.isEmpty() ? tr("Spoiler")
-		                                          : spoilerHint
-		                  : message;
-		// sorting order in contact list
-		emit m_model->setLastExchangedRequested(jid, QDateTime::currentDateTimeUtc());
-		emit m_model->setLastMessageRequested(jid, lastMessage);
-	}
-}
-
-void RosterManager::handleMessage(const QXmppMessage &msg)
-{
-	if (msg.body().isEmpty() || msg.type() == QXmppMessage::Error)
-		return;
-
-	// msg.from() can be our JID, if it's a carbon/forward from another client
-	QString fromJid = QXmppUtils::jidToBareJid(msg.from());
-	bool sentByMe = fromJid == m_client->configuration().jidBare();
-	QString contactJid = sentByMe ? QXmppUtils::jidToBareJid(msg.to())
-	                              : fromJid;
-
-	// update last exchanged datetime (sorting order in contact list)
-	emit m_model->setLastExchangedRequested(contactJid, QDateTime::currentDateTimeUtc());
-
-	// update unread message counter, if chat is not active
-	if (sentByMe) {
-		// if we sent a message (with another device), reset counter
-		emit m_model->updateItemRequested(contactJid, [](RosterItem &item) {
-			item.setUnreadMessages(0);
-		});
-	} else if (m_currentChatJid != contactJid) {
-		emit m_model->updateItemRequested(contactJid, [](RosterItem &item) {
-			item.setUnreadMessages(item.unreadMessages() + 1);
-		});
-	}
-
-	// Update last message of the contact
-	QString lastMessage;
-	if (msg.isSpoiler()) {
-		if (msg.spoilerHint().isEmpty()) {
-			lastMessage = tr("Spoiler");
-		} else {
-			lastMessage = msg.spoilerHint();
-		}
-	} else {
-		lastMessage = msg.body();
-	}
-
-	emit Kaidan::instance()->rosterModel()->setLastMessageRequested(contactJid, lastMessage);
-}
