@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -29,21 +29,16 @@
  */
 
 #include "RosterModel.h"
+
 // Kaidan
+#include "AccountManager.h"
 #include "RosterDb.h"
 #include "MessageModel.h"
 #include "Kaidan.h"
-// C++
-#include <functional>
-// Qt
-#include <QSqlDatabase>
-#include <QSqlError>
-#include <QSqlQuery>
-#include <QSqlRecord>
 
 RosterModel::RosterModel(RosterDb *rosterDb, QObject *parent)
         : QAbstractListModel(parent),
-          rosterDb(rosterDb)
+	  m_rosterDb(rosterDb)
 {
 	connect(rosterDb, &RosterDb::itemsFetched,
 		this, &RosterModel::handleItemsFetched);
@@ -66,19 +61,12 @@ RosterModel::RosterModel(RosterDb *rosterDb, QObject *parent)
 	connect(this, &RosterModel::replaceItemsRequested,
 		rosterDb, &RosterDb::replaceItems);
 
-	// This is only done in the model, the database is updated automatically by the new
-	// messages:
-	connect(this, &RosterModel::setLastMessageRequested,
-	        this, &RosterModel::setLastMessage);
-	connect(this, &RosterModel::setLastExchangedRequested,
-	        this, &RosterModel::setLastExchanged);
-
-	connect(Kaidan::instance(), &Kaidan::jidChanged, this, [=]() {
+	connect(AccountManager::instance(), &AccountManager::jidChanged, this, [=]() {
 		beginResetModel();
 		m_items.clear();
 		endResetModel();
 
-		emit rosterDb->fetchItemsRequested(Kaidan::instance()->jid());
+		emit rosterDb->fetchItemsRequested(AccountManager::instance()->jid());
 	});
 }
 
@@ -90,6 +78,9 @@ void RosterModel::setMessageModel(MessageModel *model)
 			item.setUnreadMessages(0);
 		});
 	});
+
+	connect(model, &MessageModel::addMessageRequested,
+	        this, &RosterModel::handleMessageAdded);
 }
 
 bool RosterModel::isEmpty() const
@@ -232,30 +223,61 @@ void RosterModel::replaceItems(const QHash<QString, RosterItem> &items)
 	handleItemsFetched(newItems);
 }
 
-void RosterModel::setLastMessage(const QString &contactJid, const QString &newLastMessage)
+void RosterModel::handleMessageAdded(const Message &message)
 {
-	for (int i = 0; i < m_items.length(); i++) {
-		if (m_items.at(i).jid() == contactJid) {
-			m_items[i].setLastMessage(newLastMessage);
-			emit dataChanged(index(i), index(i), QVector<int>() << int(LastMessageRole));
-			return;
-		}
-	}
-}
+	const auto contactJid = message.sentByMe() ? message.to() : message.from();
+	auto itr = std::find_if(m_items.begin(), m_items.end(), [&contactJid](const RosterItem &item) {
+		return item.jid() == contactJid;
+	});
 
-void RosterModel::setLastExchanged(const QString &contactJid, const QDateTime &newLastExchanged)
-{
-	for (int i = 0; i < m_items.length(); i++) {
-		if (m_items.at(i).jid() == contactJid) {
-			// update item
-			m_items[i].setLastExchanged(newLastExchanged);
-			emit dataChanged(index(i), index(i), QVector<int>() << int(LastExchangedRole));
+	// contact not found
+	if (itr == m_items.end())
+		return;
 
-			// Move row to correct position
-			updateItemPosition(i);
-			return;
-		}
+	// new message is older than most recent event
+	if (itr->lastExchanged() > message.stamp())
+		return;
+
+	QVector<int> changedRoles = {
+		int(LastExchangedRole)
+	};
+
+	// last exchanged
+	itr->setLastExchanged(message.stamp());
+
+	// last message
+	const auto lastMessage = message.previewText();
+	if (itr->lastMessage() != lastMessage) {
+		itr->setLastMessage(lastMessage);
+		changedRoles << int(LastMessageRole);
 	}
+
+	// unread messages counter
+	std::optional<int> newUnreadMessages;
+	if (message.sentByMe()) {
+		// if we sent a message (with another device), reset counter
+		newUnreadMessages = 0;
+	} else if (Kaidan::instance()->messageModel()->currentChatJid() != contactJid) {
+		// increase counter, if chat isn't open
+		newUnreadMessages = itr->unreadMessages() + 1;
+	}
+
+	if (newUnreadMessages.has_value()) {
+		itr->setUnreadMessages(*newUnreadMessages);
+		changedRoles << int(UnreadMessagesRole);
+
+		emit m_rosterDb->updateItemRequested(contactJid, [=](RosterItem &item) {
+			item.setUnreadMessages(*newUnreadMessages);
+		});
+	}
+
+	// notify gui
+	const auto i = std::distance(m_items.begin(), itr);
+	const auto modelIndex = index(i);
+	emit dataChanged(modelIndex, modelIndex, changedRoles);
+
+	// move row to correct position
+	updateItemPosition(i);
 }
 
 void RosterModel::insertContact(int i, const RosterItem &item)
