@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -29,19 +29,22 @@
  */
 
 #include "VCardManager.h"
-#include "AvatarFileStorage.h"
-#include "Kaidan.h"
+
 #include <QXmppClient.h>
 #include <QXmppUtils.h>
 #include <QXmppVCardIq.h>
 
-VCardManager::VCardManager(QXmppClient *client, AvatarFileStorage *avatars, QObject *parent)
-	: QObject(parent), client(client), manager(client->findExtension<QXmppVCardManager>()), avatarStorage(avatars)
+#include "AvatarFileStorage.h"
+#include "Kaidan.h"
+
+VCardManager::VCardManager(ClientWorker *clientWorker, QXmppClient *client, AvatarFileStorage *avatars, QObject *parent)
+	: QObject(parent), m_clientWorker(clientWorker), m_client(client), m_manager(client->findExtension<QXmppVCardManager>()), m_avatarStorage(avatars)
 {
-	connect(manager, &QXmppVCardManager::vCardReceived, this, &VCardManager::handleVCard);
-	connect(client, &QXmppClient::presenceReceived, this, &VCardManager::handlePresence);
-	connect(manager, &QXmppVCardManager::clientVCardReceived, this, &VCardManager::handleClientVCardReceived);
-	connect(Kaidan::instance(), &Kaidan::vCardRequested, this, &VCardManager::fetchVCard);
+	connect(m_manager, &QXmppVCardManager::vCardReceived, this, &VCardManager::handleVCardReceived);
+	connect(m_client, &QXmppClient::presenceReceived, this, &VCardManager::handlePresenceReceived);
+	connect(m_manager, &QXmppVCardManager::clientVCardReceived, this, &VCardManager::handleClientVCardReceived);
+	connect(Kaidan::instance(), &Kaidan::vCardRequested, this, &VCardManager::requestVCard);
+	connect(Kaidan::instance(), &Kaidan::changeDisplayName, this, &VCardManager::changeNickname);
 
 	// Currently we're not requesting the own VCard on every connection because it is probably
 	// way too resource intensive on mobile connections with many reconnects.
@@ -52,61 +55,66 @@ VCardManager::VCardManager(QXmppClient *client, AvatarFileStorage *avatars, QObj
 	//                         User Avatar to vCard-Based Avatars Conversion)
 }
 
-void VCardManager::fetchVCard(const QString& jid)
+void VCardManager::requestVCard(const QString &jid)
 {
-	if (client->state() == QXmppClient::ConnectedState)
-		client->findExtension<QXmppVCardManager>()->requestVCard(jid);
+	if (m_client->state() == QXmppClient::ConnectedState)
+		m_client->findExtension<QXmppVCardManager>()->requestVCard(jid);
 	else
 		qWarning() << "[VCardManager] Could not fetch VCard: Not connected to a server";
 }
 
-void VCardManager::handleVCard(const QXmppVCardIq &iq)
+void VCardManager::handleVCardReceived(const QXmppVCardIq &iq)
 {
 	if (!iq.photo().isEmpty()) {
-		avatarStorage->addAvatar(QXmppUtils::jidToBareJid(iq.from().isEmpty() ? client->configuration().jid() : iq.from()), iq.photo());
+		m_avatarStorage->addAvatar(QXmppUtils::jidToBareJid(iq.from().isEmpty() ? m_client->configuration().jid() : iq.from()), iq.photo());
 	}
 
 	emit vCardReceived(iq);
 }
 
-void VCardManager::fetchClientVCard()
+void VCardManager::requestClientVCard()
 {
-	manager->requestClientVCard();
+	m_manager->requestClientVCard();
 }
 
 void VCardManager::handleClientVCardReceived()
 {
-	if (!m_nicknameToBeSetAfterFetchingCurrentVCard.isEmpty())
-		updateNicknameAfterFetchingCurrentVCard();
+	if (!m_nicknameToBeSetAfterReceivingCurrentVCard.isEmpty())
+		changeNicknameAfterReceivingCurrentVCard();
 }
 
-void VCardManager::handlePresence(const QXmppPresence &presence)
+void VCardManager::handlePresenceReceived(const QXmppPresence &presence)
 {
 	if (presence.vCardUpdateType() == QXmppPresence::VCardUpdateValidPhoto) {
-		QString hash = avatarStorage->getHashOfJid(QXmppUtils::jidToBareJid(presence.from()));
+		QString hash = m_avatarStorage->getHashOfJid(QXmppUtils::jidToBareJid(presence.from()));
 		QString newHash = presence.photoHash().toHex();
 
 		// check if hash differs and we need to refetch the avatar
 		if (hash != newHash)
-			manager->requestVCard(QXmppUtils::jidToBareJid(presence.from()));
+			m_manager->requestVCard(QXmppUtils::jidToBareJid(presence.from()));
 
 	} else if (presence.vCardUpdateType() == QXmppPresence::VCardUpdateNoPhoto) {
 		QString bareJid = QXmppUtils::jidToBareJid(presence.from());
-		avatarStorage->clearAvatar(bareJid);
+		m_avatarStorage->clearAvatar(bareJid);
 	}
 	// ignore VCardUpdateNone (protocol unsupported) and VCardUpdateNotReady
 }
 
-void VCardManager::updateNickname(const QString &nickname)
+void VCardManager::changeNickname(const QString &nickname)
 {
-	m_nicknameToBeSetAfterFetchingCurrentVCard = nickname;
-	fetchClientVCard();
+	m_clientWorker->startTask(
+		[=] () {
+			m_nicknameToBeSetAfterReceivingCurrentVCard = nickname;
+			requestClientVCard();
+		}
+	);
 }
 
-void VCardManager::updateNicknameAfterFetchingCurrentVCard()
+void VCardManager::changeNicknameAfterReceivingCurrentVCard()
 {
-	QXmppVCardIq vCardIq = manager->clientVCard();
-	vCardIq.setNickName(m_nicknameToBeSetAfterFetchingCurrentVCard);
-	manager->setClientVCard(vCardIq);
-	m_nicknameToBeSetAfterFetchingCurrentVCard = QString();
+	QXmppVCardIq vCardIq = m_manager->clientVCard();
+	vCardIq.setNickName(m_nicknameToBeSetAfterReceivingCurrentVCard);
+	m_manager->setClientVCard(vCardIq);
+	m_nicknameToBeSetAfterReceivingCurrentVCard.clear();
+	m_clientWorker->finishTask();
 }
