@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@
  */
 
 // Qt
-#include <QAbstractSocket>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QDebug>
@@ -38,17 +37,15 @@
 #include <QLibraryInfo>
 #include <QLocale>
 #include <QQmlApplicationEngine>
-#include <QQmlContext>
 #include <QTranslator>
-#include <QStandardPaths>
 #include <qqml.h>
 
 // QXmpp
-#include "qxmpp-exts/QXmppUploadManager.h"
 #include <QXmppClient.h>
-#include <QXmppRegisterIq.h>
+#include <QXmppVersionIq.h>
 
 // Kaidan
+#include "AccountManager.h"
 #include "AvatarFileStorage.h"
 #include "BitsOfBinaryImageProvider.h"
 #include "CredentialsGenerator.h"
@@ -66,18 +63,18 @@
 #include "RosterFilterProxyModel.h"
 #include "StatusBar.h"
 #include "ServerListModel.h"
-#include "UploadManager.h"
-#include "Utils.h"
 #include "QrCodeGenerator.h"
 #include "QrCodeScannerFilter.h"
 #include "VCardModel.h"
+#include "UserDevicesModel.h"
 #include "CameraModel.h"
 #include "AudioDeviceModel.h"
-#include "MediaSettingModel.h"
 #include "MediaUtils.h"
 #include "MediaRecorder.h"
 #include "GuiStyle.h"
 
+Q_DECLARE_METATYPE(QXmppVersionIq)
+
 #ifdef STATIC_BUILD
 #include "static_plugins.h"
 #endif
@@ -216,7 +213,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<MessageModel*>("MessageModel*");
 	qRegisterMetaType<AvatarFileStorage*>("AvatarFileStorage*");
 	qRegisterMetaType<QXmppPresence>("QXmppPresence");
-	qRegisterMetaType<ClientWorker::Credentials>("Credentials");
 	qRegisterMetaType<Qt::ApplicationState>("Qt::ApplicationState");
 	qRegisterMetaType<QXmppClient::State>("QXmppClient::State");
 	qRegisterMetaType<MessageType>("MessageType");
@@ -227,7 +223,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<QHash<QString,RosterItem>>("QHash<QString,RosterItem>");
 	qRegisterMetaType<std::function<void(RosterItem&)>>("std::function<void(RosterItem&)>");
 	qRegisterMetaType<std::function<void(Message&)>>("std::function<void(Message&)>");
-	qRegisterMetaType<ClientWorker::Credentials>("ClientWorker::Credentials");
 	qRegisterMetaType<QXmppVCardIq>("QXmppVCardIq");
 	qRegisterMetaType<QMimeType>();
 	qRegisterMetaType<CameraInfo>();
@@ -238,6 +233,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<VideoEncoderSettings>();
 	qRegisterMetaType<CredentialsValidator*>();
 	qRegisterMetaType<QXmppStanza::Error>("QXmppStanza::Error");
+	qRegisterMetaType<QXmppVersionIq>();
 
 	// Enums for c++ member calls using enums
 	qRegisterMetaType<Enums::ConnectionState>();
@@ -306,17 +302,17 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	//
 	// Kaidan back-end
 	//
-	auto *kaidan = new Kaidan(&app, !parser.isSet("disable-xml-log"));
+	Kaidan kaidan(&app, !parser.isSet("disable-xml-log"));
 
 #if !defined(Q_OS_IOS) && !defined(Q_OS_ANDROID)
 	// receive messages from other instances of Kaidan
 	Kaidan::connect(&app, &SingleApplication::receivedMessage,
-	                kaidan, &Kaidan::receiveMessage);
+	                &kaidan, &Kaidan::receiveMessage);
 #endif
 
 	// open the XMPP-URI/link (if given)
 	if (const auto positionalArguments = parser.positionalArguments(); !positionalArguments.isEmpty())
-		kaidan->addOpenUri(positionalArguments.first());
+		kaidan.addOpenUri(positionalArguments.first());
 
 	//
 	// QML-GUI
@@ -332,14 +328,19 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
 	// QtQuickControls2 Style
 	if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
-#ifdef Q_OS_WIN
-		const QString defaultStyle = QStringLiteral("Universal");
-#else
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
 		const QString defaultStyle = QStringLiteral("Material");
+#else
+		const QString defaultStyle = QStringLiteral("org.kde.desktop");
 #endif
 		qDebug() << "QT_QUICK_CONTROLS_STYLE not set, setting to" << defaultStyle;
 		qputenv("QT_QUICK_CONTROLS_STYLE", defaultStyle.toLatin1());
 	}
+
+#ifdef Q_OS_WIN
+	QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+
 	// QML type bindings
 #ifdef STATIC_BUILD
 	KirigamiPlugin::getInstance().registerTypes();
@@ -361,6 +362,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterType<MediaSettingsVideoCodecModel>(APPLICATION_ID, 1, 0, "MediaSettingsVideoCodecModel");
 	qmlRegisterType<MediaSettingsVideoFrameRateModel>(APPLICATION_ID, 1, 0, "MediaSettingsVideoFrameRateModel");
 	qmlRegisterType<MediaRecorder>(APPLICATION_ID, 1, 0, "MediaRecorder");
+	qmlRegisterType<UserDevicesModel>(APPLICATION_ID, 1, 0, "UserDevicesModel");
 	qmlRegisterType<CredentialsGenerator>(APPLICATION_ID, 1, 0, "CredentialsGenerator");
 	qmlRegisterType<CredentialsValidator>(APPLICATION_ID, 1, 0, "CredentialsValidator");
 	qmlRegisterType<QrCodeGenerator>(APPLICATION_ID, 1, 0, "QrCodeGenerator");
@@ -393,12 +395,16 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterSingletonType<QmlUtils>(APPLICATION_ID, 1, 0, "Utils", [](QQmlEngine *, QJSEngine *) {
 		return static_cast<QObject*>(QmlUtils::instance());
 	});
-	qmlRegisterSingletonType<Kaidan>(APPLICATION_ID, 1, 0, "Kaidan", [](QQmlEngine *, QJSEngine *) {
-		return static_cast<QObject*>(Kaidan::instance());
+	qmlRegisterSingletonType<Kaidan>(APPLICATION_ID, 1, 0, "Kaidan", [](QQmlEngine *engine, QJSEngine *) {
+		engine->setObjectOwnership(Kaidan::instance(), QQmlEngine::CppOwnership);
+		return static_cast<QObject *>(Kaidan::instance());
 	});
 	qmlRegisterSingletonType<GuiStyle>(APPLICATION_ID, 1, 0, "Style", [](QQmlEngine *, QJSEngine *) {
 		return static_cast<QObject *>(new GuiStyle(QCoreApplication::instance()));
 	});
+	qmlRegisterSingletonType<AccountManager>(APPLICATION_ID, 1, 0, "AccountManager", [](QQmlEngine *, QJSEngine *) {
+		return static_cast<QObject *>(AccountManager::instance());
+	});
 
 	engine.load(QUrl("qrc:/qml/main.qml"));
 	if (engine.rootObjects().isEmpty())
