@@ -53,9 +53,11 @@ REPLACE_USER_IDS = [
 	("X oiseauroch <tobias.ollive@mailoo.org>", "oiseauroch <tobias.ollive@mailoo.org>"),
 	("X ssantos <ssantos@web.de>", "ssantos <ssantos@web.de>"),
 	("X Txaume <txaumevw@gmail.com>", "Txaume <txaumevw@gmail.com>"),
-	("X mondstern <hello@mondstern.tk>", "mondstern <hello@mondstern.tk>"),
+	("X mondstern <hello@mondstern.tk>", "mondstern <mondstern@snopyta.org>"),
+	("X mondstern <mondstern@snopyta.org>", "mondstern <mondstern@snopyta.org>"),
 	("Jeannette L <j.lavoie@net-c.ca>", "Jeannette Lavoie <j.lavoie@net-c.ca>"),
 	("aevw _ <arcanevw@tuta.io>", "aevw <arcanevw@tuta.io>"),
+    ("Coucouf _ <coucouf@coucouf.fr>", "Coucouf <coucouf@coucouf.fr>"),
 ]
 
 # These user ids will be excluded from any targets
@@ -400,6 +402,14 @@ def main():
 				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2020")
 			}
 		),
+		CopyrightTarget(
+			files = ["data/images/mic0.svg", "data/images/mic1.svg", "data/images/mic2.svg", "data/images/mic3.svg"],
+			licenseName = "CC-BY-SA-4.0",
+			authorList = {
+				"Jonah Brüchert <jbb@kaidan.im>": CopyrightAuthor(years = "2020"),
+				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2020")
+			}
+		),
 		CopyrightTarget(
 			files = ["utils/convert-prl-libs-to-cmake.pl"],
 			licenseName = "MIT-Apple",
